@@ -39,42 +39,45 @@
 # include "FallocFileAllocationIterator.h"
 #endif // HAVE_POSIX_FALLOCATE
 #include "DiskWriter.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
 AbstractSingleDiskAdaptor::AbstractSingleDiskAdaptor():
-  totalLength(0), _readOnly(false) {}
+  totalLength_(0), readOnly_(false) {}
 
 AbstractSingleDiskAdaptor::~AbstractSingleDiskAdaptor() {}
 
 void AbstractSingleDiskAdaptor::initAndOpenFile()
 {
-  diskWriter->initAndOpenFile(totalLength);
+  diskWriter_->initAndOpenFile(totalLength_);
 }
 
 void AbstractSingleDiskAdaptor::openFile()
 {
-  diskWriter->openFile(totalLength);
+  diskWriter_->openFile(totalLength_);
 }
 
 void AbstractSingleDiskAdaptor::closeFile()
 {
-  diskWriter->closeFile();
+  diskWriter_->closeFile();
 }
 
 void AbstractSingleDiskAdaptor::openExistingFile()
 {
-  diskWriter->openExistingFile(totalLength);
+  diskWriter_->openExistingFile(totalLength_);
 }
 
-void AbstractSingleDiskAdaptor::writeData(const unsigned char* data, size_t len, off_t offset)
+void AbstractSingleDiskAdaptor::writeData
+(const unsigned char* data, size_t len, off_t offset)
 {
-  diskWriter->writeData(data, len, offset);
+  diskWriter_->writeData(data, len, offset);
 }
 
-ssize_t AbstractSingleDiskAdaptor::readData(unsigned char* data, size_t len, off_t offset)
+ssize_t AbstractSingleDiskAdaptor::readData
+(unsigned char* data, size_t len, off_t offset)
 {
-  return diskWriter->readData(data, len, offset);
+  return diskWriter_->readData(data, len, offset);
 }
 
 bool AbstractSingleDiskAdaptor::fileExists()
@@ -89,21 +92,24 @@ uint64_t AbstractSingleDiskAdaptor::size()
 
 void AbstractSingleDiskAdaptor::truncate(uint64_t length)
 {
-  diskWriter->truncate(length);
+  diskWriter_->truncate(length);
 }
 
-FileAllocationIteratorHandle AbstractSingleDiskAdaptor::fileAllocationIterator()
+FileAllocationIteratorHandle
+AbstractSingleDiskAdaptor::fileAllocationIterator()
 {
 #ifdef HAVE_POSIX_FALLOCATE
-  if(_fallocate) {
+  if(doesFallocate()) {
     SharedHandle<FallocFileAllocationIterator> h
-      (new FallocFileAllocationIterator(this, size(), totalLength));
+      (new FallocFileAllocationIterator
+       (diskWriter_.get(), size() ,totalLength_));
     return h;
   } else
 #endif // HAVE_POSIX_FALLOCATE
     {
       SingleFileAllocationIteratorHandle h
-        (new SingleFileAllocationIterator(this, size(), totalLength));
+        (new SingleFileAllocationIterator
+         (diskWriter_.get(), size(), totalLength_));
       h->init();
       return h;
     }
@@ -111,41 +117,42 @@ FileAllocationIteratorHandle AbstractSingleDiskAdaptor::fileAllocationIterator()
 
 void AbstractSingleDiskAdaptor::enableDirectIO()
 {
-  diskWriter->enableDirectIO();
+  diskWriter_->enableDirectIO();
 }
 
 void AbstractSingleDiskAdaptor::disableDirectIO()
 {
-  diskWriter->disableDirectIO();
+  diskWriter_->disableDirectIO();
 }
 
 void AbstractSingleDiskAdaptor::enableReadOnly()
 {
-  diskWriter->enableReadOnly();
-  _readOnly = true;
+  diskWriter_->enableReadOnly();
+  readOnly_ = true;
 }
 
 void AbstractSingleDiskAdaptor::disableReadOnly()
 {
-  diskWriter->disableReadOnly();
-  _readOnly = false;
+  diskWriter_->disableReadOnly();
+  readOnly_ = false;
 }
 
 void AbstractSingleDiskAdaptor::cutTrailingGarbage()
 {
-  if(File(getFilePath()).size() > totalLength) {
-    diskWriter->truncate(totalLength);
+  if(File(getFilePath()).size() > totalLength_) {
+    diskWriter_->truncate(totalLength_);
   }
 }
   
-void AbstractSingleDiskAdaptor::setDiskWriter(const DiskWriterHandle& diskWriter)
+void AbstractSingleDiskAdaptor::setDiskWriter
+(const DiskWriterHandle& diskWriter)
 {
-  this->diskWriter = diskWriter;
+  diskWriter_ = diskWriter;
 }
 
 void AbstractSingleDiskAdaptor::setTotalLength(const uint64_t& totalLength)
 {
-  this->totalLength = totalLength;
+  totalLength_ = totalLength;
 }
 
 } // namespace aria2
