@@ -46,51 +46,51 @@ using namespace aria2::expr;
 namespace aria2 {
 
 BitfieldMan::BitfieldMan(size_t blockLength, uint64_t totalLength)
-  :blockLength(blockLength),
-   totalLength(totalLength),
-   bitfieldLength(0),
-   blocks(0),
-   filterEnabled(false),
-   bitfield(0),
-   useBitfield(0),
-   filterBitfield(0),
-   cachedNumMissingBlock(0),
-   cachedNumFilteredBlock(0),
-   cachedCompletedLength(0),
-   cachedFilteredComletedLength(0),
-   cachedFilteredTotalLength(0)
+  :blockLength_(blockLength),
+   totalLength_(totalLength),
+   bitfieldLength_(0),
+   blocks_(0),
+   filterEnabled_(false),
+   bitfield_(0),
+   useBitfield_(0),
+   filterBitfield_(0),
+   cachedNumMissingBlock_(0),
+   cachedNumFilteredBlock_(0),
+   cachedCompletedLength_(0),
+   cachedFilteredCompletedLength_(0),
+   cachedFilteredTotalLength_(0)
 {
-  if(blockLength > 0 && totalLength > 0) {
-    blocks = totalLength/blockLength+(totalLength%blockLength ? 1 : 0);
-    bitfieldLength = blocks/8+(blocks%8 ? 1 : 0);
-    bitfield = new unsigned char[bitfieldLength];
-    useBitfield = new unsigned char[bitfieldLength];
-    memset(bitfield, 0, bitfieldLength);
-    memset(useBitfield, 0, bitfieldLength);
+  if(blockLength_ > 0 && totalLength_ > 0) {
+    blocks_ = totalLength_/blockLength_+(totalLength_%blockLength_ ? 1 : 0);
+    bitfieldLength_ = blocks_/8+(blocks_%8 ? 1 : 0);
+    bitfield_ = new unsigned char[bitfieldLength_];
+    useBitfield_ = new unsigned char[bitfieldLength_];
+    memset(bitfield_, 0, bitfieldLength_);
+    memset(useBitfield_, 0, bitfieldLength_);
     updateCache();
   }
 }
 
 BitfieldMan::BitfieldMan(const BitfieldMan& bitfieldMan)
-  :blockLength(bitfieldMan.blockLength),
-   totalLength(bitfieldMan.totalLength),
-   bitfieldLength(bitfieldMan.bitfieldLength),
-   blocks(bitfieldMan.blocks),
-   filterEnabled(bitfieldMan.filterEnabled),
-   bitfield(new unsigned char[bitfieldLength]),
-   useBitfield(new unsigned char[bitfieldLength]),
-   filterBitfield(0),
-   cachedNumMissingBlock(0),
-   cachedNumFilteredBlock(0),
-   cachedCompletedLength(0),
-   cachedFilteredComletedLength(0),
-   cachedFilteredTotalLength(0)
+  :blockLength_(bitfieldMan.blockLength_),
+   totalLength_(bitfieldMan.totalLength_),
+   bitfieldLength_(bitfieldMan.bitfieldLength_),
+   blocks_(bitfieldMan.blocks_),
+   filterEnabled_(bitfieldMan.filterEnabled_),
+   bitfield_(new unsigned char[bitfieldLength_]),
+   useBitfield_(new unsigned char[bitfieldLength_]),
+   filterBitfield_(0),
+   cachedNumMissingBlock_(0),
+   cachedNumFilteredBlock_(0),
+   cachedCompletedLength_(0),
+   cachedFilteredCompletedLength_(0),
+   cachedFilteredTotalLength_(0)
 {
-  memcpy(bitfield, bitfieldMan.bitfield, bitfieldLength);
-  memcpy(useBitfield, bitfieldMan.useBitfield, bitfieldLength);
-  if(filterEnabled) {
-    filterBitfield = new unsigned char[bitfieldLength];
-    memcpy(filterBitfield, bitfieldMan.filterBitfield, bitfieldLength);
+  memcpy(bitfield_, bitfieldMan.bitfield_, bitfieldLength_);
+  memcpy(useBitfield_, bitfieldMan.useBitfield_, bitfieldLength_);
+  if(filterEnabled_) {
+    filterBitfield_ = new unsigned char[bitfieldLength_];
+    memcpy(filterBitfield_, bitfieldMan.filterBitfield_, bitfieldLength_);
   }
   updateCache();
 }
@@ -98,26 +98,26 @@ BitfieldMan::BitfieldMan(const BitfieldMan& bitfieldMan)
 BitfieldMan& BitfieldMan::operator=(const BitfieldMan& bitfieldMan)
 {
   if(this != &bitfieldMan) {
-    blockLength = bitfieldMan.blockLength;
-    totalLength = bitfieldMan.totalLength;
-    blocks = bitfieldMan.blocks;
-    bitfieldLength = bitfieldMan.bitfieldLength;
-    filterEnabled = bitfieldMan.filterEnabled;
+    blockLength_ = bitfieldMan.blockLength_;
+    totalLength_ = bitfieldMan.totalLength_;
+    blocks_ = bitfieldMan.blocks_;
+    bitfieldLength_ = bitfieldMan.bitfieldLength_;
+    filterEnabled_ = bitfieldMan.filterEnabled_;
 
-    delete [] bitfield;
-    bitfield = new unsigned char[bitfieldLength];
-    memcpy(bitfield, bitfieldMan.bitfield, bitfieldLength);
+    delete [] bitfield_;
+    bitfield_ = new unsigned char[bitfieldLength_];
+    memcpy(bitfield_, bitfieldMan.bitfield_, bitfieldLength_);
 
-    delete [] useBitfield;
-    useBitfield = new unsigned char[bitfieldLength];
-    memcpy(useBitfield, bitfieldMan.useBitfield, bitfieldLength);
+    delete [] useBitfield_;
+    useBitfield_ = new unsigned char[bitfieldLength_];
+    memcpy(useBitfield_, bitfieldMan.useBitfield_, bitfieldLength_);
 
-    delete [] filterBitfield;
-    if(filterEnabled) {
-      filterBitfield = new unsigned char[bitfieldLength];
-      memcpy(filterBitfield, bitfieldMan.filterBitfield, bitfieldLength);
+    delete [] filterBitfield_;
+    if(filterEnabled_) {
+      filterBitfield_ = new unsigned char[bitfieldLength_];
+      memcpy(filterBitfield_, bitfieldMan.filterBitfield_, bitfieldLength_);
     } else {
-      filterBitfield = 0;
+      filterBitfield_ = 0;
     }
 
     updateCache();
@@ -126,16 +126,16 @@ BitfieldMan& BitfieldMan::operator=(const BitfieldMan& bitfieldMan)
 }
 
 BitfieldMan::~BitfieldMan() {
-  delete [] bitfield;
-  delete [] useBitfield;
-  delete [] filterBitfield;
+  delete [] bitfield_;
+  delete [] useBitfield_;
+  delete [] filterBitfield_;
 }
 
 size_t BitfieldMan::getBlockLength(size_t index) const
 {
-  if(index == blocks-1) {
+  if(index == blocks_-1) {
     return getLastBlockLength();
-  } else if(index < blocks-1) {
+  } else if(index < blocks_-1) {
     return getBlockLength();
   } else {
     return 0;
@@ -145,14 +145,14 @@ size_t BitfieldMan::getBlockLength(size_t index) const
 bool BitfieldMan::hasMissingPiece
 (const unsigned char* peerBitfield, size_t length) const
 {
-  if(bitfieldLength != length) {
+  if(bitfieldLength_ != length) {
     return false;
   }
   bool retval = false;
-  for(size_t i = 0; i < bitfieldLength; ++i) {
-    unsigned char temp = peerBitfield[i] & ~bitfield[i];
-    if(filterEnabled) {
-      temp &= filterBitfield[i];
+  for(size_t i = 0; i < bitfieldLength_; ++i) {
+    unsigned char temp = peerBitfield[i] & ~bitfield_[i];
+    if(filterEnabled_) {
+      temp &= filterBitfield_[i];
     }
     if(temp&0xff) {
       retval = true;
@@ -164,37 +164,37 @@ bool BitfieldMan::hasMissingPiece
 
 bool BitfieldMan::getFirstMissingUnusedIndex(size_t& index) const
 {
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return bitfield::getFirstMissingIndex
-      (index, ~array(bitfield)&~array(useBitfield)&array(filterBitfield),
-       blocks);
+      (index, ~array(bitfield_)&~array(useBitfield_)&array(filterBitfield_),
+       blocks_);
   } else {
     return bitfield::getFirstMissingIndex
-      (index, ~array(bitfield)&~array(useBitfield), blocks);
+      (index, ~array(bitfield_)&~array(useBitfield_), blocks_);
   }
 }
 
 size_t BitfieldMan::getFirstNMissingUnusedIndex
 (std::vector<size_t>& out, size_t n) const
 {
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return bitfield::getFirstNMissingIndex
       (std::back_inserter(out), n,
-       ~array(bitfield)&~array(useBitfield)&array(filterBitfield), blocks);
+       ~array(bitfield_)&~array(useBitfield_)&array(filterBitfield_), blocks_);
   } else {
     return bitfield::getFirstNMissingIndex
       (std::back_inserter(out), n,
-       ~array(bitfield)&~array(useBitfield), blocks);
+       ~array(bitfield_)&~array(useBitfield_), blocks_);
   }
 }
 
 bool BitfieldMan::getFirstMissingIndex(size_t& index) const
 {
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return bitfield::getFirstMissingIndex
-      (index, ~array(bitfield)&array(filterBitfield), blocks);
+      (index, ~array(bitfield_)&array(filterBitfield_), blocks_);
   } else {
-    return bitfield::getFirstMissingIndex(index, ~array(bitfield), blocks);
+    return bitfield::getFirstMissingIndex(index, ~array(bitfield_), blocks_);
   }
 }
 
@@ -262,14 +262,14 @@ bool BitfieldMan::getSparseMissingUnusedIndex
  const unsigned char* ignoreBitfield,
  size_t ignoreBitfieldLength) const
 {
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return aria2::getSparseMissingUnusedIndex
-      (index, array(ignoreBitfield)|~array(filterBitfield)|array(bitfield)|array(useBitfield),
-       useBitfield, blocks);
+      (index, array(ignoreBitfield)|~array(filterBitfield_)|array(bitfield_)|array(useBitfield_),
+       useBitfield_, blocks_);
   } else {
     return aria2::getSparseMissingUnusedIndex
-      (index, array(ignoreBitfield)|array(bitfield)|array(useBitfield),
-       useBitfield, blocks);
+      (index, array(ignoreBitfield)|array(bitfield_)|array(useBitfield_),
+       useBitfield_, blocks_);
   }
 }
 
@@ -290,12 +290,12 @@ static bool copyBitfield(unsigned char* dst, const Array& src, size_t blocks)
 bool BitfieldMan::getAllMissingIndexes(unsigned char* misbitfield, size_t len)
   const
 {
-  assert(len == bitfieldLength);
-  if(filterEnabled) {
+  assert(len == bitfieldLength_);
+  if(filterEnabled_) {
     return copyBitfield
-      (misbitfield, ~array(bitfield)&array(filterBitfield), blocks);
+      (misbitfield, ~array(bitfield_)&array(filterBitfield_), blocks_);
   } else {
-    return copyBitfield(misbitfield, ~array(bitfield), blocks);
+    return copyBitfield(misbitfield, ~array(bitfield_), blocks_);
   }
 }
 
@@ -303,18 +303,19 @@ bool BitfieldMan::getAllMissingIndexes(unsigned char* misbitfield, size_t len,
                                        const unsigned char* peerBitfield,
                                        size_t peerBitfieldLength) const
 {
-  assert(len == bitfieldLength);
-  if(bitfieldLength != peerBitfieldLength) {
+  assert(len == bitfieldLength_);
+  if(bitfieldLength_ != peerBitfieldLength) {
     return false;
   }
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return copyBitfield
-      (misbitfield, ~array(bitfield)&array(peerBitfield)&array(filterBitfield),
-       blocks);
+      (misbitfield,
+       ~array(bitfield_)&array(peerBitfield)&array(filterBitfield_),
+       blocks_);
   } else {
     return copyBitfield
-      (misbitfield, ~array(bitfield)&array(peerBitfield),
-       blocks);
+      (misbitfield, ~array(bitfield_)&array(peerBitfield),
+       blocks_);
   }
 }
 
@@ -323,52 +324,53 @@ bool BitfieldMan::getAllMissingUnusedIndexes(unsigned char* misbitfield,
                                              const unsigned char* peerBitfield,
                                              size_t peerBitfieldLength) const
 {
-  assert(len == bitfieldLength);
-  if(bitfieldLength != peerBitfieldLength) {
+  assert(len == bitfieldLength_);
+  if(bitfieldLength_ != peerBitfieldLength) {
     return false;
   }
-  if(filterEnabled) {
+  if(filterEnabled_) {
     return copyBitfield
       (misbitfield,
-       ~array(bitfield)&~array(useBitfield)&array(peerBitfield)&array(filterBitfield),
-       blocks);
+       ~array(bitfield_)&~array(useBitfield_)&array(peerBitfield)&
+       array(filterBitfield_),
+       blocks_);
   } else {
     return copyBitfield
       (misbitfield,
-       ~array(bitfield)&~array(useBitfield)&array(peerBitfield),
-       blocks);
+       ~array(bitfield_)&~array(useBitfield_)&array(peerBitfield),
+       blocks_);
   }
 }
 
 size_t BitfieldMan::countMissingBlock() const {
-  return cachedNumMissingBlock;
+  return cachedNumMissingBlock_;
 }
 
 size_t BitfieldMan::countMissingBlockNow() const {
-  if(filterEnabled) {
-    array_ptr<unsigned char> temp(new unsigned char[bitfieldLength]);
-    for(size_t i = 0; i < bitfieldLength; ++i) {
-      temp[i] = bitfield[i]&filterBitfield[i];
+  if(filterEnabled_) {
+    array_ptr<unsigned char> temp(new unsigned char[bitfieldLength_]);
+    for(size_t i = 0; i < bitfieldLength_; ++i) {
+      temp[i] = bitfield_[i]&filterBitfield_[i];
     }
-    size_t count =  bitfield::countSetBit(filterBitfield, blocks)-
-      bitfield::countSetBit(temp, blocks);
+    size_t count =  bitfield::countSetBit(filterBitfield_, blocks_)-
+      bitfield::countSetBit(temp, blocks_);
     return count;
   } else {
-    return blocks-bitfield::countSetBit(bitfield, blocks);
+    return blocks_-bitfield::countSetBit(bitfield_, blocks_);
   }
 }
 
 size_t BitfieldMan::countFilteredBlockNow() const {
-  if(filterEnabled) {
-    return bitfield::countSetBit(filterBitfield, blocks);
+  if(filterEnabled_) {
+    return bitfield::countSetBit(filterBitfield_, blocks_);
   } else {
     return 0;
   }
 }
 
 bool BitfieldMan::setBitInternal(unsigned char* bitfield, size_t index, bool on) {
-  if(blocks <= index) { return false; }
-  unsigned char mask = 128 >> index%8;
+  if(blocks_ <= index) { return false; }
+  unsigned char mask = 128 >> (index%8);
   if(on) {
     bitfield[index/8] |= mask;
   } else {
@@ -378,29 +380,29 @@ bool BitfieldMan::setBitInternal(unsigned char* bitfield, size_t index, bool on)
 }
 
 bool BitfieldMan::setUseBit(size_t index) {
-  return setBitInternal(useBitfield, index, true);
+  return setBitInternal(useBitfield_, index, true);
 }
 
 bool BitfieldMan::unsetUseBit(size_t index) {
-  return setBitInternal(useBitfield, index, false);
+  return setBitInternal(useBitfield_, index, false);
 }
 
 bool BitfieldMan::setBit(size_t index) {
-  bool b = setBitInternal(bitfield, index, true);
+  bool b = setBitInternal(bitfield_, index, true);
   updateCache();
   return b;
 }
 
 bool BitfieldMan::unsetBit(size_t index) {
-  bool b = setBitInternal(bitfield, index, false);
+  bool b = setBitInternal(bitfield_, index, false);
   updateCache();
   return b;
 }
 
 bool BitfieldMan::isFilteredAllBitSet() const {
-  if(filterEnabled) {
-    for(size_t i = 0; i < bitfieldLength; ++i) {
-      if((bitfield[i]&filterBitfield[i]) != filterBitfield[i]) {
+  if(filterEnabled_) {
+    for(size_t i = 0; i < bitfieldLength_; ++i) {
+      if((bitfield_[i]&filterBitfield_[i]) != filterBitfield_[i]) {
         return false;
       }
     }
@@ -421,86 +423,82 @@ static bool testAllBitSet
       return false;
     }
   }
-  unsigned char b = ~((128 >> (blocks-1)%8)-1);
-  if(bitfield[length-1] != b) {
-    return false;
-  }
-  return true;
+  return bitfield[length-1] == bitfield::lastByteMask(blocks);
 }
 
 bool BitfieldMan::isAllBitSet() const
 {
-  return testAllBitSet(bitfield, bitfieldLength, blocks);
+  return testAllBitSet(bitfield_, bitfieldLength_, blocks_);
 }
 
 bool BitfieldMan::isAllFilterBitSet() const
 {
-  if(!filterBitfield) {
+  if(!filterBitfield_) {
     return false;
   }
-  return testAllBitSet(filterBitfield, bitfieldLength, blocks);
+  return testAllBitSet(filterBitfield_, bitfieldLength_, blocks_);
 }
 
 bool BitfieldMan::isBitSet(size_t index) const
 {
-  return bitfield::test(bitfield, blocks, index);
+  return bitfield::test(bitfield_, blocks_, index);
 }
 
 bool BitfieldMan::isUseBitSet(size_t index) const
 {
-  return bitfield::test(useBitfield, blocks, index);
+  return bitfield::test(useBitfield_, blocks_, index);
 }
 
 void BitfieldMan::setBitfield(const unsigned char* bitfield, size_t bitfieldLength) {
-  if(this->bitfieldLength != bitfieldLength) {
+  if(bitfieldLength_ != bitfieldLength) {
     return;
   }
-  memcpy(this->bitfield, bitfield, this->bitfieldLength);
-  memset(this->useBitfield, 0, this->bitfieldLength);
+  memcpy(bitfield_, bitfield, bitfieldLength_);
+  memset(useBitfield_, 0, bitfieldLength_);
   updateCache();
 }
 
 void BitfieldMan::clearAllBit() {
-  memset(this->bitfield, 0, this->bitfieldLength);
+  memset(bitfield_, 0, bitfieldLength_);
   updateCache();
 }
 
 void BitfieldMan::setAllBit() {
-  for(size_t i = 0; i < blocks; ++i) {
-    setBitInternal(bitfield, i, true);
+  for(size_t i = 0; i < blocks_; ++i) {
+    setBitInternal(bitfield_, i, true);
   }
   updateCache();
 }
 
 void BitfieldMan::clearAllUseBit() {
-  memset(this->useBitfield, 0, this->bitfieldLength);
+  memset(useBitfield_, 0, bitfieldLength_);
   updateCache();
 }
 
 void BitfieldMan::setAllUseBit() {
-  for(size_t i = 0; i < blocks; ++i) {
-    setBitInternal(useBitfield, i, true);
+  for(size_t i = 0; i < blocks_; ++i) {
+    setBitInternal(useBitfield_, i, true);
   }
 }
 
 bool BitfieldMan::setFilterBit(size_t index) {
-  return setBitInternal(filterBitfield, index, true);
+  return setBitInternal(filterBitfield_, index, true);
 }
 
 void BitfieldMan::ensureFilterBitfield()
 {
-  if(!filterBitfield) {
-    filterBitfield = new unsigned char[bitfieldLength];
-    memset(filterBitfield, 0, bitfieldLength);
+  if(!filterBitfield_) {
+    filterBitfield_ = new unsigned char[bitfieldLength_];
+    memset(filterBitfield_, 0, bitfieldLength_);
   }
 }
 
 void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
   ensureFilterBitfield();
   if(length > 0) {
-    size_t startBlock = offset/blockLength;
-    size_t endBlock = (offset+length-1)/blockLength;
-    for(size_t i = startBlock; i <= endBlock && i < blocks; i++) {
+    size_t startBlock = offset/blockLength_;
+    size_t endBlock = (offset+length-1)/blockLength_;
+    for(size_t i = startBlock; i <= endBlock && i < blocks_; i++) {
       setFilterBit(i);
     }
   }
@@ -510,10 +508,10 @@ void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
 void BitfieldMan::removeFilter(uint64_t offset, uint64_t length) {
   ensureFilterBitfield();
   if(length > 0) {
-    size_t startBlock = offset/blockLength;
-    size_t endBlock = (offset+length-1)/blockLength;
-    for(size_t i = startBlock; i <= endBlock && i < blocks; i++) {
-      setBitInternal(filterBitfield, i, false);
+    size_t startBlock = offset/blockLength_;
+    size_t endBlock = (offset+length-1)/blockLength_;
+    for(size_t i = startBlock; i <= endBlock && i < blocks_; i++) {
+      setBitInternal(filterBitfield_, i, false);
     }
   }
   updateCache();
@@ -522,16 +520,16 @@ void BitfieldMan::removeFilter(uint64_t offset, uint64_t length) {
 void BitfieldMan::addNotFilter(uint64_t offset, uint64_t length)
 {
   ensureFilterBitfield();
-  if(length > 0 && blocks > 0) {
-    size_t startBlock = offset/blockLength;
-    if(blocks <= startBlock) {
-      startBlock = blocks;
+  if(length > 0 && blocks_ > 0) {
+    size_t startBlock = offset/blockLength_;
+    if(blocks_ <= startBlock) {
+      startBlock = blocks_;
     }
-    size_t endBlock = (offset+length-1)/blockLength;
+    size_t endBlock = (offset+length-1)/blockLength_;
     for(size_t i = 0; i < startBlock; ++i) {
       setFilterBit(i);
     }
-    for(size_t i = endBlock+1; i < blocks; ++i) {
+    for(size_t i = endBlock+1; i < blocks_; ++i) {
       setFilterBit(i);
     }
   }
@@ -540,61 +538,61 @@ void BitfieldMan::addNotFilter(uint64_t offset, uint64_t length)
 
 void BitfieldMan::enableFilter() {
   ensureFilterBitfield();
-  filterEnabled = true;
+  filterEnabled_ = true;
   updateCache();
 }
 
 void BitfieldMan::disableFilter() {
-  filterEnabled = false;
+  filterEnabled_ = false;
   updateCache();
 }
 
 void BitfieldMan::clearFilter() {
-  if(filterBitfield) {
-    delete [] filterBitfield;
-    filterBitfield = 0;
+  if(filterBitfield_) {
+    delete [] filterBitfield_;
+    filterBitfield_ = 0;
   }
-  filterEnabled = false;
+  filterEnabled_ = false;
   updateCache();
 }
 
 uint64_t BitfieldMan::getFilteredTotalLengthNow() const {
-  if(!filterBitfield) {
+  if(!filterBitfield_) {
     return 0;
   }
-  size_t filteredBlocks = bitfield::countSetBit(filterBitfield, blocks);
+  size_t filteredBlocks = bitfield::countSetBit(filterBitfield_, blocks_);
   if(filteredBlocks == 0) {
     return 0;
   }
-  if(bitfield::test(filterBitfield, blocks, blocks-1)) {
-    return ((uint64_t)filteredBlocks-1)*blockLength+getLastBlockLength();
+  if(bitfield::test(filterBitfield_, blocks_, blocks_-1)) {
+    return ((uint64_t)filteredBlocks-1)*blockLength_+getLastBlockLength();
   } else {
-    return ((uint64_t)filteredBlocks)*blockLength;
+    return ((uint64_t)filteredBlocks)*blockLength_;
   }
 }
 
 uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
   unsigned char* temp;
   if(useFilter) {
-    temp = new unsigned char[bitfieldLength];
-    for(size_t i = 0; i < bitfieldLength; ++i) {
-      temp[i] = bitfield[i];
-      if(filterEnabled) {
-        temp[i] &= filterBitfield[i];
+    temp = new unsigned char[bitfieldLength_];
+    for(size_t i = 0; i < bitfieldLength_; ++i) {
+      temp[i] = bitfield_[i];
+      if(filterEnabled_) {
+        temp[i] &= filterBitfield_[i];
       }
     }
   } else {
-    temp = bitfield;
+    temp = bitfield_;
   }
-  size_t completedBlocks = bitfield::countSetBit(temp, blocks);
+  size_t completedBlocks = bitfield::countSetBit(temp, blocks_);
   uint64_t completedLength = 0;
   if(completedBlocks == 0) {
     completedLength = 0;
   } else {
-    if(bitfield::test(temp, blocks, blocks-1)) {
-      completedLength = ((uint64_t)completedBlocks-1)*blockLength+getLastBlockLength();
+    if(bitfield::test(temp, blocks_, blocks_-1)) {
+      completedLength = ((uint64_t)completedBlocks-1)*blockLength_+getLastBlockLength();
     } else {
-      completedLength = ((uint64_t)completedBlocks)*blockLength;
+      completedLength = ((uint64_t)completedBlocks)*blockLength_;
     }
   }
   if(useFilter) {
@@ -613,11 +611,11 @@ uint64_t BitfieldMan::getFilteredCompletedLengthNow() const {
 
 void BitfieldMan::updateCache()
 {
-  cachedNumMissingBlock = countMissingBlockNow();
-  cachedNumFilteredBlock = countFilteredBlockNow();
-  cachedFilteredTotalLength = getFilteredTotalLengthNow();
-  cachedCompletedLength = getCompletedLengthNow();
-  cachedFilteredComletedLength = getFilteredCompletedLengthNow();
+  cachedNumMissingBlock_ = countMissingBlockNow();
+  cachedNumFilteredBlock_ = countFilteredBlockNow();
+  cachedFilteredTotalLength_ = getFilteredTotalLengthNow();
+  cachedCompletedLength_ = getCompletedLengthNow();
+  cachedFilteredCompletedLength_ = getFilteredCompletedLengthNow();
 }
 
 bool BitfieldMan::isBitRangeSet(size_t startIndex, size_t endIndex) const
@@ -651,14 +649,14 @@ bool BitfieldMan::isBitSetOffsetRange(uint64_t offset, uint64_t length) const
   if(length <= 0) {
     return false;
   }
-  if(totalLength <= offset) {
+  if(totalLength_ <= offset) {
     return false;
   }
-  if(totalLength < offset+length) {
-    length = totalLength-offset;
+  if(totalLength_ < offset+length) {
+    length = totalLength_-offset;
   }
-  size_t startBlock = offset/blockLength;
-  size_t endBlock = (offset+length-1)/blockLength;
+  size_t startBlock = offset/blockLength_;
+  size_t endBlock = (offset+length-1)/blockLength_;
   for(size_t i = startBlock; i <= endBlock; i++) {
     if(!isBitSet(i)) {
       return false;
@@ -669,11 +667,11 @@ bool BitfieldMan::isBitSetOffsetRange(uint64_t offset, uint64_t length) const
 
 uint64_t BitfieldMan::getMissingUnusedLength(size_t startingIndex) const
 {
-  if(startingIndex < 0 || blocks <= startingIndex) {
+  if(startingIndex < 0 || blocks_ <= startingIndex) {
     return 0;
   }
   uint64_t length = 0;
-  for(size_t i = startingIndex; i < blocks; ++i) {
+  for(size_t i = startingIndex; i < blocks_; ++i) {
     if(isBitSet(i) || isUseBitSet(i)) {
       break;
     }
