@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -47,50 +47,64 @@ class MessageDigestContext;
 
 class DownloadCommand : public AbstractCommand {
 private:
-  time_t startupIdleTime;
-  unsigned int lowestDownloadSpeedLimit;
-  SharedHandle<PeerStat> peerStat;
+  unsigned char* buf_;
+
+  time_t startupIdleTime_;
+  unsigned int lowestDownloadSpeedLimit_;
+  SharedHandle<PeerStat> peerStat_;
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-  bool _pieceHashValidationEnabled;
+  bool pieceHashValidationEnabled_;
 
-  SharedHandle<MessageDigestContext> _messageDigestContext;
+  SharedHandle<MessageDigestContext> messageDigestContext_;
 
 #endif // ENABLE_MESSAGE_DIGEST
 
   void validatePieceHash(const SharedHandle<Segment>& segment,
-			 const std::string& expectedPieceHash,
-			 const std::string& actualPieceHash);
+                         const std::string& expectedPieceHash,
+                         const std::string& actualPieceHash);
 
   void checkLowestDownloadSpeed() const;
+
+  SharedHandle<Decoder> transferEncodingDecoder_;
+
+  SharedHandle<Decoder> contentEncodingDecoder_;
 protected:
-  SharedHandle<Decoder> _transferEncodingDecoder;
-
-  SharedHandle<Decoder> _contentEncodingDecoder;
-
   virtual bool executeInternal();
 
   virtual bool prepareForNextSegment();
-
 public:
-  DownloadCommand(int cuid,
-		  const SharedHandle<Request>& req,
-		  RequestGroup* requestGroup,
-		  DownloadEngine* e,
-		  const SharedHandle<SocketCore>& s);
+  DownloadCommand(cuid_t cuid,
+                  const SharedHandle<Request>& req,
+                  const SharedHandle<FileEntry>& fileEntry,
+                  RequestGroup* requestGroup,
+                  DownloadEngine* e,
+                  const SharedHandle<SocketCore>& s);
   virtual ~DownloadCommand();
 
+  const SharedHandle<Decoder>& getTransferEncodingDecoder() const
+  {
+    return transferEncodingDecoder_;
+  }
+
   void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);
 
-  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);
-
-  void setStartupIdleTime(time_t startupIdleTime) {
-    this->startupIdleTime = startupIdleTime;
+  const SharedHandle<Decoder>& getContentEncodingDecoder() const
+  {
+    return contentEncodingDecoder_;
   }
 
-  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit) {
-    this->lowestDownloadSpeedLimit = lowestDownloadSpeedLimit;
+  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);
+
+  void setStartupIdleTime(time_t startupIdleTime)
+  {
+    startupIdleTime_ = startupIdleTime;
+  }
+
+  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit)
+  {
+    lowestDownloadSpeedLimit_ = lowestDownloadSpeedLimit;
   }
 };
 
