@@ -71,6 +71,9 @@
 #include "HttpResponse.h"
 #include "DlRetryEx.h"
 #include "CookieStorage.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
@@ -80,102 +83,105 @@ FtpNegotiationCommand::FtpNegotiationCommand
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- const SocketHandle& s,
+ const SocketHandle& socket,
  Seq seq,
  const std::string& baseWorkingDir):
-  AbstractCommand(cuid, req, fileEntry, requestGroup, e, s), sequence(seq),
-  ftp(new FtpConnection(cuid, socket, req,
+  AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket), sequence_(seq),
+  ftp_(new FtpConnection(cuid, socket, req,
                         e->getAuthConfigFactory()->createAuthConfig
                         (req, requestGroup->getOption().get()),
                         getOption().get()))
 {
-  ftp->setBaseWorkingDir(baseWorkingDir);
+  ftp_->setBaseWorkingDir(baseWorkingDir);
   if(seq == SEQ_RECV_GREETING) {
     setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   }
   disableReadCheckSocket();
-  setWriteCheckSocket(socket);
+  setWriteCheckSocket(getSocket());
 }
 
 FtpNegotiationCommand::~FtpNegotiationCommand() {}
 
 bool FtpNegotiationCommand::executeInternal() {
-  while(processSequence(_segments.front()));
-  if(sequence == SEQ_RETRY) {
+  while(processSequence(getSegments().front()));
+  if(sequence_ == SEQ_RETRY) {
     return prepareForRetry(0);
-  } else if(sequence == SEQ_NEGOTIATION_COMPLETED) {
+  } else if(sequence_ == SEQ_NEGOTIATION_COMPLETED) {
     FtpDownloadCommand* command =
       new FtpDownloadCommand
-      (cuid, req, _fileEntry, _requestGroup, ftp, e, dataSocket, socket);
+      (getCuid(), getRequest(), getFileEntry(), getRequestGroup(), ftp_,
+       getDownloadEngine(), dataSocket_, getSocket());
     command->setStartupIdleTime(getOption()->getAsInt(PREF_STARTUP_IDLE_TIME));
-    command->setLowestDownloadSpeedLimit(getOption()->getAsInt(PREF_LOWEST_SPEED_LIMIT));
-    if(!_fileEntry->isSingleHostMultiConnectionEnabled()) {
-      _fileEntry->removeURIWhoseHostnameIs(req->getHost());
+    command->setLowestDownloadSpeedLimit
+      (getOption()->getAsInt(PREF_LOWEST_SPEED_LIMIT));
+    if(!getFileEntry()->isSingleHostMultiConnectionEnabled()) {
+      getFileEntry()->removeURIWhoseHostnameIs(getRequest()->getHost());
     }
-    _requestGroup->getURISelector()->tuneDownloadCommand
-      (_fileEntry->getRemainingUris(), command);
-    e->commands.push_back(command);
+    getRequestGroup()->getURISelector()->tuneDownloadCommand
+      (getFileEntry()->getRemainingUris(), command);
+    getDownloadEngine()->addCommand(command);
     return true;
-  } else if(sequence == SEQ_HEAD_OK || sequence == SEQ_DOWNLOAD_ALREADY_COMPLETED) {
+  } else if(sequence_ == SEQ_HEAD_OK ||
+            sequence_ == SEQ_DOWNLOAD_ALREADY_COMPLETED) {
     return true;
-  } else if(sequence == SEQ_FILE_PREPARATION) {
+  } else if(sequence_ == SEQ_FILE_PREPARATION) {
     if(getOption()->getAsBool(PREF_FTP_PASV)) {
-      sequence = SEQ_SEND_PASV;
+      sequence_ = SEQ_SEND_PASV;
     } else {
-      sequence = SEQ_PREPARE_SERVER_SOCKET;
+      sequence_ = SEQ_PREPARE_SERVER_SOCKET;
     }
     return false;
-  } else if(sequence == SEQ_EXIT) {
+  } else if(sequence_ == SEQ_EXIT) {
     return true;
   } else {
-    e->commands.push_back(this);
+    getDownloadEngine()->addCommand(this);
     return false;
   }
 }
 
 bool FtpNegotiationCommand::recvGreeting() {
   if(!checkIfConnectionEstablished
-     (socket, _connectedHostname, _connectedAddr, _connectedPort)) {
-    sequence = SEQ_EXIT;
+     (getSocket(), connectedHostname_, connectedAddr_, connectedPort_)) {
+    sequence_ = SEQ_EXIT;
     return false;
   }
-  setTimeout(_requestGroup->getTimeout());
+  setTimeout(getRequestGroup()->getTimeout());
   //socket->setBlockingMode();
   disableWriteCheckSocket();
-  setReadCheckSocket(socket);
+  setReadCheckSocket(getSocket());
 
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 220) {
     throw DL_ABORT_EX(EX_CONNECTION_FAILED);
   }
-  sequence = SEQ_SEND_USER;
+  sequence_ = SEQ_SEND_USER;
 
   return true;
 }
 
 bool FtpNegotiationCommand::sendUser() {
-  if(ftp->sendUser()) {
+  if(ftp_->sendUser()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_USER;
+    sequence_ = SEQ_RECV_USER;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvUser() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   switch(status) {
   case 0:
     return false;
   case 230:
-    sequence = SEQ_SEND_TYPE;
+    sequence_ = SEQ_SEND_TYPE;
     break;
   case 331:
-    sequence = SEQ_SEND_PASS;
+    sequence_ = SEQ_SEND_PASS;
     break;
   default:
     throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
@@ -184,56 +190,56 @@ bool FtpNegotiationCommand::recvUser() {
 }
 
 bool FtpNegotiationCommand::sendPass() {
-  if(ftp->sendPass()) {
+  if(ftp_->sendPass()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_PASS;
+    sequence_ = SEQ_RECV_PASS;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvPass() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 230) {
     throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  sequence = SEQ_SEND_TYPE;
+  sequence_ = SEQ_SEND_TYPE;
   return true;
 }
 
 bool FtpNegotiationCommand::sendType() {
-  if(ftp->sendType()) {
+  if(ftp_->sendType()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_TYPE;
+    sequence_ = SEQ_RECV_TYPE;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvType() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 200) {
     throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  sequence = SEQ_SEND_PWD;
+  sequence_ = SEQ_SEND_PWD;
   return true;
 }
 
 bool FtpNegotiationCommand::sendPwd()
 {
-  if(ftp->sendPwd()) {
+  if(ftp_->sendPwd()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_PWD;
+    sequence_ = SEQ_RECV_PWD;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
@@ -241,42 +247,42 @@ bool FtpNegotiationCommand::sendPwd()
 bool FtpNegotiationCommand::recvPwd()
 {
   std::string pwd;
-  unsigned int status = ftp->receivePwdResponse(pwd);
+  unsigned int status = ftp_->receivePwdResponse(pwd);
   if(status == 0) {
     return false;
   }
   if(status != 257) {
     throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  ftp->setBaseWorkingDir(pwd);
-  if(logger->info()) {
-    logger->info("CUID#%s - base working directory is '%s'",
-                 util::itos(cuid).c_str(), pwd.c_str());
+  ftp_->setBaseWorkingDir(pwd);
+  if(getLogger()->info()) {
+    getLogger()->info("CUID#%s - base working directory is '%s'",
+                      util::itos(getCuid()).c_str(), pwd.c_str());
   }
-  sequence = SEQ_SEND_CWD;
+  sequence_ = SEQ_SEND_CWD;
   return true;
 }
 
 bool FtpNegotiationCommand::sendCwd() {
   // Calling setReadCheckSocket() is needed when the socket is reused, 
-  setReadCheckSocket(socket);
-  if(ftp->sendCwd()) {
+  setReadCheckSocket(getSocket());
+  if(ftp_->sendCwd()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_CWD;
+    sequence_ = SEQ_RECV_CWD;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvCwd() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 250) {
     poolConnection();
-    _requestGroup->increaseAndValidateFileNotFoundCount();
+    getRequestGroup()->increaseAndValidateFileNotFoundCount();
     if (status == 550)
       throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
                          downloadresultcode::RESOURCE_NOT_FOUND);
@@ -284,20 +290,20 @@ bool FtpNegotiationCommand::recvCwd() {
       throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   if(getOption()->getAsBool(PREF_REMOTE_TIME)) {
-    sequence = SEQ_SEND_MDTM;
+    sequence_ = SEQ_SEND_MDTM;
   } else {
-    sequence = SEQ_SEND_SIZE;
+    sequence_ = SEQ_SEND_SIZE;
   }
   return true;
 }
 
 bool FtpNegotiationCommand::sendMdtm()
 {
-  if(ftp->sendMdtm()) {
+  if(ftp_->sendMdtm()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_MDTM;
+    sequence_ = SEQ_RECV_MDTM;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
@@ -305,138 +311,146 @@ bool FtpNegotiationCommand::sendMdtm()
 bool FtpNegotiationCommand::recvMdtm()
 {
   Time lastModifiedTime = Time::null();
-  unsigned int status = ftp->receiveMdtmResponse(lastModifiedTime);
+  unsigned int status = ftp_->receiveMdtmResponse(lastModifiedTime);
   if(status == 0) {
     return false;
   }
   if(status == 213) {
     if(lastModifiedTime.good()) {
-      _requestGroup->updateLastModifiedTime(lastModifiedTime);
+      getRequestGroup()->updateLastModifiedTime(lastModifiedTime);
       time_t t = lastModifiedTime.getTime();
       struct tm* tms = gmtime(&t); // returned struct is statically allocated.
       if(tms) {
-        if(logger->debug()) {
-          logger->debug("MDTM result was parsed as: %s GMT", asctime(tms));
+        if(getLogger()->debug()) {
+          getLogger()->debug("MDTM result was parsed as: %s GMT", asctime(tms));
         }
       } else {
-        if(logger->debug()) {
-          logger->debug("gmtime() failed for MDTM result.");
+        if(getLogger()->debug()) {
+          getLogger()->debug("gmtime() failed for MDTM result.");
         }
       }
     } else {
-      if(logger->debug()) {
-        logger->debug("MDTM response was returned, but it seems not to be a"
-                      " time value as in specified in RFC3659.");
+      if(getLogger()->debug()) {
+        getLogger()->debug("MDTM response was returned, but it seems not to be"
+                           " a time value as in specified in RFC3659.");
       }
     }
   } else {
-    if(logger->info()) {
-      logger->info("CUID#%s - MDTM command failed.", util::itos(cuid).c_str());
+    if(getLogger()->info()) {
+      getLogger()->info("CUID#%s - MDTM command failed.",
+                        util::itos(getCuid()).c_str());
     }
   }
-  sequence = SEQ_SEND_SIZE;
+  sequence_ = SEQ_SEND_SIZE;
   return true;  
 }
 
 bool FtpNegotiationCommand::sendSize() {
-  if(ftp->sendSize()) {
+  if(ftp_->sendSize()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_SIZE;
+    sequence_ = SEQ_RECV_SIZE;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 {
-  _fileEntry->setLength(totalLength);
-  if(_fileEntry->getPath().empty()) {
-    _fileEntry->setPath
+  getFileEntry()->setLength(totalLength);
+  if(getFileEntry()->getPath().empty()) {
+    getFileEntry()->setPath
       (util::applyDir
        (getDownloadContext()->getDir(),
-        util::fixTaintedBasename(util::percentDecode(req->getFile()))));
+        util::fixTaintedBasename
+        (util::percentDecode(getRequest()->getFile()))));
   }
-  _requestGroup->preDownloadProcessing();
-  if(e->_requestGroupMan->isSameFileBeingDownloaded(_requestGroup)) {
+  getRequestGroup()->preDownloadProcessing();
+  if(getDownloadEngine()->getRequestGroupMan()->
+     isSameFileBeingDownloaded(getRequestGroup())) {
     throw DOWNLOAD_FAILURE_EXCEPTION
       (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-                    _requestGroup->getFirstFilePath().c_str()).str());
+                    getRequestGroup()->getFirstFilePath().c_str()).str());
   }
   if(totalLength == 0) {
 
     if(getOption()->getAsBool(PREF_FTP_PASV)) {
-      sequence = SEQ_SEND_PASV;
+      sequence_ = SEQ_SEND_PASV;
     } else {
-      sequence = SEQ_PREPARE_SERVER_SOCKET;
+      sequence_ = SEQ_PREPARE_SERVER_SOCKET;
     }
 
     if(getOption()->getAsBool(PREF_DRY_RUN)) {
-      _requestGroup->initPieceStorage();
+      getRequestGroup()->initPieceStorage();
       onDryRunFileFound();
       return false;
     }
 
-    if(_requestGroup->downloadFinishedByFileLength()) {
-      _requestGroup->initPieceStorage();
-      _requestGroup->getPieceStorage()->markAllPiecesDone();
-      sequence = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+    if(getRequestGroup()->downloadFinishedByFileLength()) {
+      getRequestGroup()->initPieceStorage();
+      getPieceStorage()->markAllPiecesDone();
+      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
 
-      logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                     util::itos(_requestGroup->getGID()).c_str(),
-                     _requestGroup->getFirstFilePath().c_str());
+      getLogger()->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                          util::itos(getRequestGroup()->getGID()).c_str(),
+                          getRequestGroup()->getFirstFilePath().c_str());
 
       poolConnection();
 
       return false;
     }
 
-    _requestGroup->shouldCancelDownloadForSafety();
-    _requestGroup->initPieceStorage();
-    _requestGroup->getPieceStorage()->getDiskAdaptor()->initAndOpenFile();
+    getRequestGroup()->shouldCancelDownloadForSafety();
+    getRequestGroup()->initPieceStorage();
+    getPieceStorage()->getDiskAdaptor()->initAndOpenFile();
 
     if(getDownloadContext()->knowsTotalLength()) {
-      sequence = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
       poolConnection();
       return false;
     }
     // We have to make sure that command that has Request object must
     // have segment after PieceStorage is initialized. See
     // AbstractCommand::execute()
-    _requestGroup->getSegmentMan()->getSegment(cuid, 0);
+    getSegmentMan()->getSegment(getCuid(), 0);
     return true;
   } else {
-    _requestGroup->adjustFilename
-      (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
-                                        (_requestGroup->getDownloadContext(),
-                                         SharedHandle<PieceStorage>(),
-                                         getOption().get())));
-    _requestGroup->initPieceStorage();
+    getRequestGroup()->adjustFilename
+      (SharedHandle<BtProgressInfoFile>
+       (new DefaultBtProgressInfoFile
+        (getDownloadContext(),
+         SharedHandle<PieceStorage>(),
+         getOption().get())));
+    getRequestGroup()->initPieceStorage();
 
     if(getOption()->getAsBool(PREF_DRY_RUN)) {
       onDryRunFileFound();
       return false;
     }
 
-    BtProgressInfoFileHandle infoFile(new DefaultBtProgressInfoFile(_requestGroup->getDownloadContext(), _requestGroup->getPieceStorage(), getOption().get()));
-    if(!infoFile->exists() && _requestGroup->downloadFinishedByFileLength()) {
-      _requestGroup->getPieceStorage()->markAllPiecesDone();
+    BtProgressInfoFileHandle infoFile
+      (new DefaultBtProgressInfoFile(getDownloadContext(),
+                                     getPieceStorage(),
+                                     getOption().get()));
+    if(!infoFile->exists() &&
+       getRequestGroup()->downloadFinishedByFileLength()) {
+      getPieceStorage()->markAllPiecesDone();
 
-      sequence = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
       
-      logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                     util::itos(_requestGroup->getGID()).c_str(),
-                     _requestGroup->getFirstFilePath().c_str());
+      getLogger()->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                          util::itos(getRequestGroup()->getGID()).c_str(),
+                          getRequestGroup()->getFirstFilePath().c_str());
 
       poolConnection();
       
       return false;
     }
-    _requestGroup->loadAndOpenFile(infoFile);
+    getRequestGroup()->loadAndOpenFile(infoFile);
     // We have to make sure that command that has Request object must
     // have segment after PieceStorage is initialized. See
     // AbstractCommand::execute()
-    _requestGroup->getSegmentMan()->getSegment(cuid, 0);
+    getSegmentMan()->getSegment(getCuid(), 0);
 
     prepareForNextAction(this);
 
@@ -447,7 +461,7 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 
 bool FtpNegotiationCommand::recvSize() {
   uint64_t size = 0;
-  unsigned int status = ftp->receiveSizeResponse(size);
+  unsigned int status = ftp_->receiveSizeResponse(size);
   if(status == 0) {
     return false;
   }
@@ -455,26 +469,27 @@ bool FtpNegotiationCommand::recvSize() {
 
     if(size > INT64_MAX) {
       throw DL_ABORT_EX
-        (StringFormat(EX_TOO_LARGE_FILE, util::uitos(size, true).c_str()).str());
+        (StringFormat(EX_TOO_LARGE_FILE,
+                      util::uitos(size, true).c_str()).str());
     }
-    if(_requestGroup->getPieceStorage().isNull()) {
+    if(getPieceStorage().isNull()) {
 
-      sequence = SEQ_FILE_PREPARATION;
+      sequence_ = SEQ_FILE_PREPARATION;
       return onFileSizeDetermined(size);
 
     } else {
-      _requestGroup->validateTotalLength(_fileEntry->getLength(), size);
+      getRequestGroup()->validateTotalLength(getFileEntry()->getLength(), size);
     }
 
   } else {
-    if(logger->info()) {
-      logger->info("CUID#%s - The remote FTP Server doesn't recognize SIZE"
-                   " command. Continue.", util::itos(cuid).c_str());
+    if(getLogger()->info()) {
+      getLogger()->info("CUID#%s - The remote FTP Server doesn't recognize SIZE"
+                        " command. Continue.", util::itos(getCuid()).c_str());
     }
     // Even if one of the other servers waiting in the queue supports SIZE
     // command, resuming and segmented downloading are disabled when the first
     // contacted FTP server doesn't support it.
-    if(_requestGroup->getPieceStorage().isNull()) {
+    if(getPieceStorage().isNull()) {
       getDownloadContext()->markTotalLengthIsUnknown();
       return onFileSizeDetermined(0);
 
@@ -483,62 +498,62 @@ bool FtpNegotiationCommand::recvSize() {
     // wrong file to be downloaded if user-specified URL is wrong.
   }
   if(getOption()->getAsBool(PREF_FTP_PASV)) {
-    sequence = SEQ_SEND_PASV;
+    sequence_ = SEQ_SEND_PASV;
   } else {
-    sequence = SEQ_PREPARE_SERVER_SOCKET;
+    sequence_ = SEQ_PREPARE_SERVER_SOCKET;
   }
   return true;
 }
 
 void FtpNegotiationCommand::afterFileAllocation()
 {
-  setReadCheckSocket(socket);
+  setReadCheckSocket(getSocket());
 }
 
 bool FtpNegotiationCommand::prepareServerSocket()
 {
-  serverSocket = ftp->createServerSocket();
-  sequence = SEQ_SEND_PORT;
+  serverSocket_ = ftp_->createServerSocket();
+  sequence_ = SEQ_SEND_PORT;
   return true;
 }
 
 bool FtpNegotiationCommand::sendPort() {
   afterFileAllocation();
-  if(ftp->sendPort(serverSocket)) {
+  if(ftp_->sendPort(serverSocket_)) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_PORT;
+    sequence_ = SEQ_RECV_PORT;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvPort() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 200) {
     throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
-  sequence = SEQ_SEND_REST;
+  sequence_ = SEQ_SEND_REST;
   return true;
 }
 
 bool FtpNegotiationCommand::sendPasv() {
   afterFileAllocation();
-  if(ftp->sendPasv()) {
+  if(ftp_->sendPasv()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_PASV;
+    sequence_ = SEQ_RECV_PASV;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvPasv() {
   std::pair<std::string, uint16_t> dest;
-  unsigned int status = ftp->receivePasvResponse(dest);
+  unsigned int status = ftp_->receivePasvResponse(dest);
   if(status == 0) {
     return false;
   }
@@ -547,21 +562,21 @@ bool FtpNegotiationCommand::recvPasv() {
   }
   // TODO Should we check to see that dest.first is not in noProxy list?
   if(isProxyDefined()) {
-    _dataConnAddr = dest;
-    sequence = SEQ_RESOLVE_PROXY;
+    dataConnAddr_ = dest;
+    sequence_ = SEQ_RESOLVE_PROXY;
     return true;
   } else {
     // make a data connection to the server.
-    if(logger->info()) {
-      logger->info(MSG_CONNECTING_TO_SERVER, util::itos(cuid).c_str(),
-                   dest.first.c_str(),
-                   dest.second);
+    if(getLogger()->info()) {
+      getLogger()->info(MSG_CONNECTING_TO_SERVER, util::itos(getCuid()).c_str(),
+                        dest.first.c_str(),
+                        dest.second);
     }
-    dataSocket.reset(new SocketCore());
-    dataSocket->establishConnection(dest.first, dest.second);
+    dataSocket_.reset(new SocketCore());
+    dataSocket_->establishConnection(dest.first, dest.second);
     disableReadCheckSocket();
-    setWriteCheckSocket(dataSocket);
-    sequence = SEQ_SEND_REST_PASV;
+    setWriteCheckSocket(dataSocket_);
+    sequence_ = SEQ_SEND_REST_PASV;
     return false;
   }
 }
@@ -570,51 +585,54 @@ bool FtpNegotiationCommand::resolveProxy()
 {
   SharedHandle<Request> proxyReq = createProxyRequest();
   std::vector<std::string> addrs;
-  _proxyAddr = resolveHostname
+  proxyAddr_ = resolveHostname
     (addrs, proxyReq->getHost(), proxyReq->getPort());
-  if(_proxyAddr.empty()) {
+  if(proxyAddr_.empty()) {
     return false;
   }
-  if(logger->info()) {
-    logger->info(MSG_CONNECTING_TO_SERVER, util::itos(cuid).c_str(),
-                 _proxyAddr.c_str(), proxyReq->getPort());
+  if(getLogger()->info()) {
+    getLogger()->info(MSG_CONNECTING_TO_SERVER, util::itos(getCuid()).c_str(),
+                      proxyAddr_.c_str(), proxyReq->getPort());
   }
-  dataSocket.reset(new SocketCore());                  
-  dataSocket->establishConnection(_proxyAddr, proxyReq->getPort());
+  dataSocket_.reset(new SocketCore());                  
+  dataSocket_->establishConnection(proxyAddr_, proxyReq->getPort());
   disableReadCheckSocket();
-  setWriteCheckSocket(dataSocket);
-  _http.reset(new HttpConnection(cuid, dataSocket, getOption().get()));
-  sequence = SEQ_SEND_TUNNEL_REQUEST;
+  setWriteCheckSocket(dataSocket_);
+  http_.reset(new HttpConnection(getCuid(), dataSocket_));
+  sequence_ = SEQ_SEND_TUNNEL_REQUEST;
   return false;
 }
 
 bool FtpNegotiationCommand::sendTunnelRequest()
 {
-  if(_http->sendBufferIsEmpty()) {
-    if(dataSocket->isReadable(0)) {
-      std::string error = socket->getSocketError();
+  if(http_->sendBufferIsEmpty()) {
+    if(dataSocket_->isReadable(0)) {
+      std::string error = getSocket()->getSocketError();
       if(!error.empty()) {
         SharedHandle<Request> proxyReq = createProxyRequest();
-        e->markBadIPAddress(proxyReq->getHost(),_proxyAddr,proxyReq->getPort());
-        std::string nextProxyAddr = e->findCachedIPAddress
+        getDownloadEngine()->markBadIPAddress(proxyReq->getHost(),
+                                              proxyAddr_,proxyReq->getPort());
+        std::string nextProxyAddr = getDownloadEngine()->findCachedIPAddress
           (proxyReq->getHost(), proxyReq->getPort());
         if(nextProxyAddr.empty()) {
-          e->removeCachedIPAddress(proxyReq->getHost(), proxyReq->getPort());
+          getDownloadEngine()->removeCachedIPAddress(proxyReq->getHost(),
+                                                     proxyReq->getPort());
           throw DL_RETRY_EX
             (StringFormat(MSG_ESTABLISHING_CONNECTION_FAILED,
                           error.c_str()).str());
         } else {
-          if(logger->info()) {
-            logger->info(MSG_CONNECT_FAILED_AND_RETRY,
-                         util::itos(cuid).c_str(),
-                         _proxyAddr.c_str(), proxyReq->getPort());
+          if(getLogger()->info()) {
+            getLogger()->info(MSG_CONNECT_FAILED_AND_RETRY,
+                              util::itos(getCuid()).c_str(),
+                              proxyAddr_.c_str(), proxyReq->getPort());
           }
-          _proxyAddr = nextProxyAddr;
-          if(logger->info()) {
-            logger->info(MSG_CONNECTING_TO_SERVER, util::itos(cuid).c_str(),
-                         _proxyAddr.c_str(), proxyReq->getPort());
+          proxyAddr_ = nextProxyAddr;
+          if(getLogger()->info()) {
+            getLogger()->info(MSG_CONNECTING_TO_SERVER,
+                              util::itos(getCuid()).c_str(),
+                              proxyAddr_.c_str(), proxyReq->getPort());
           }
-          dataSocket->establishConnection(_proxyAddr, proxyReq->getPort());
+          dataSocket_->establishConnection(proxyAddr_, proxyReq->getPort());
           return false;
         }
       }
@@ -623,57 +641,57 @@ bool FtpNegotiationCommand::sendTunnelRequest()
     httpRequest->setUserAgent(getOption()->get(PREF_USER_AGENT));
     SharedHandle<Request> req(new Request());
     // Construct fake URI in order to use HttpRequest
-    req->setUri(strconcat("ftp://", _dataConnAddr.first,
-                          A2STR::COLON_C, util::uitos(_dataConnAddr.second)));
+    req->setUri(strconcat("ftp://", dataConnAddr_.first,
+                          A2STR::COLON_C, util::uitos(dataConnAddr_.second)));
     httpRequest->setRequest(req);
     httpRequest->setProxyRequest(createProxyRequest());
-    _http->sendProxyRequest(httpRequest);
+    http_->sendProxyRequest(httpRequest);
   } else {
-    _http->sendPendingData();
+    http_->sendPendingData();
   }
-  if(_http->sendBufferIsEmpty()) {
+  if(http_->sendBufferIsEmpty()) {
     disableWriteCheckSocket();
-    setReadCheckSocket(dataSocket);
-    sequence = SEQ_RECV_TUNNEL_RESPONSE;
+    setReadCheckSocket(dataSocket_);
+    sequence_ = SEQ_RECV_TUNNEL_RESPONSE;
     return false;
   } else {
-    setWriteCheckSocket(dataSocket);
+    setWriteCheckSocket(dataSocket_);
     return false;
   }
 }
 
 bool FtpNegotiationCommand::recvTunnelResponse()
 {
-  SharedHandle<HttpResponse> httpResponse = _http->receiveResponse();
+  SharedHandle<HttpResponse> httpResponse = http_->receiveResponse();
   if(httpResponse.isNull()) {
     return false;
   }
   if(httpResponse->getResponseStatus() != HttpHeader::S200) {
     throw DL_RETRY_EX(EX_PROXY_CONNECTION_FAILED);
   }
-  sequence = SEQ_SEND_REST_PASV;
+  sequence_ = SEQ_SEND_REST_PASV;
   return true;
 }
 
 bool FtpNegotiationCommand::sendRestPasv(const SharedHandle<Segment>& segment) {
-  //dataSocket->setBlockingMode();
-  setReadCheckSocket(socket);
+  //dataSocket_->setBlockingMode();
+  setReadCheckSocket(getSocket());
   disableWriteCheckSocket();
   return sendRest(segment);
 }
 
 bool FtpNegotiationCommand::sendRest(const SharedHandle<Segment>& segment) {
-  if(ftp->sendRest(segment)) {
+  if(ftp_->sendRest(segment)) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_REST;
+    sequence_ = SEQ_RECV_REST;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvRest(const SharedHandle<Segment>& segment) {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -685,27 +703,27 @@ bool FtpNegotiationCommand::recvRest(const SharedHandle<Segment>& segment) {
                          downloadresultcode::CANNOT_RESUME);
     }
   }
-  sequence = SEQ_SEND_RETR;
+  sequence_ = SEQ_SEND_RETR;
   return true;
 }
 
 bool FtpNegotiationCommand::sendRetr() {
-  if(ftp->sendRetr()) {
+  if(ftp_->sendRetr()) {
     disableWriteCheckSocket();
-    sequence = SEQ_RECV_RETR;
+    sequence_ = SEQ_RECV_RETR;
   } else {
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
   }
   return false;
 }
 
 bool FtpNegotiationCommand::recvRetr() {
-  unsigned int status = ftp->receiveResponse();
+  unsigned int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 150 && status != 125) {
-    _requestGroup->increaseAndValidateFileNotFoundCount();
+    getRequestGroup()->increaseAndValidateFileNotFoundCount();
     if (status == 550)
       throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
                          downloadresultcode::RESOURCE_NOT_FOUND);
@@ -713,12 +731,12 @@ bool FtpNegotiationCommand::recvRetr() {
       throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
   }
   if(getOption()->getAsBool(PREF_FTP_PASV)) {
-    sequence = SEQ_NEGOTIATION_COMPLETED;
+    sequence_ = SEQ_NEGOTIATION_COMPLETED;
     return false;
   } else {
     disableReadCheckSocket();
-    setReadCheckSocket(serverSocket);
-    sequence = SEQ_WAIT_CONNECTION;
+    setReadCheckSocket(serverSocket_);
+    sequence_ = SEQ_WAIT_CONNECTION;
     return false;
   }
 }
@@ -726,17 +744,17 @@ bool FtpNegotiationCommand::recvRetr() {
 bool FtpNegotiationCommand::waitConnection()
 {
   disableReadCheckSocket();
-  setReadCheckSocket(socket);
-  dataSocket.reset(serverSocket->acceptConnection());
-  dataSocket->setNonBlockingMode();
-  sequence = SEQ_NEGOTIATION_COMPLETED;
+  setReadCheckSocket(getSocket());
+  dataSocket_.reset(serverSocket_->acceptConnection());
+  dataSocket_->setNonBlockingMode();
+  sequence_ = SEQ_NEGOTIATION_COMPLETED;
   return false;
 }
 
 bool FtpNegotiationCommand::processSequence
 (const SharedHandle<Segment>& segment) {
   bool doNextSequence = true;
-  switch(sequence) {
+  switch(sequence_) {
   case SEQ_RECV_GREETING:
     return recvGreeting();
   case SEQ_SEND_USER:
@@ -805,16 +823,17 @@ void FtpNegotiationCommand::poolConnection() const
 {
   if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
     std::map<std::string, std::string> options;
-    options["baseWorkingDir"] = ftp->getBaseWorkingDir();
-    e->poolSocket(req, isProxyDefined(),  socket, options);
+    options["baseWorkingDir"] = ftp_->getBaseWorkingDir();
+    getDownloadEngine()->poolSocket(getRequest(), ftp_->getUser(),
+                                    createProxyRequest(), getSocket(), options);
   }
 }
 
 void FtpNegotiationCommand::onDryRunFileFound()
 {
-  _requestGroup->getPieceStorage()->markAllPiecesDone();
+  getPieceStorage()->markAllPiecesDone();
   poolConnection();
-  sequence = SEQ_HEAD_OK;
+  sequence_ = SEQ_HEAD_OK;
 }
 
 } // namespace aria2
