@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,7 +39,7 @@
 
 #include <cassert>
 #include <string>
-#include <deque>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "Request.h"
@@ -59,37 +59,41 @@ private:
   
   static const std::string USER_AGENT;
 
-  SharedHandle<Request> request;
+  SharedHandle<Request> request_;
 
-  SharedHandle<FileEntry> _fileEntry;
+  SharedHandle<FileEntry> fileEntry_;
 
-  SharedHandle<Segment> segment;
+  SharedHandle<Segment> segment_;
 
-  bool _contentEncodingEnabled;
+  bool contentEncodingEnabled_;
 
-  std::string userAgent;
+  std::string userAgent_;
 
-  std::deque<std::string> _headers;
+  std::vector<std::string> headers_;
 
-  std::deque<std::string> _acceptTypes;
+  std::vector<std::string> acceptTypes_;
 
-  SharedHandle<CookieStorage> _cookieStorage;
+  SharedHandle<CookieStorage> cookieStorage_;
 
-  SharedHandle<AuthConfigFactory> _authConfigFactory;
+  SharedHandle<AuthConfigFactory> authConfigFactory_;
 
-  const Option* _option;
+  const Option* option_;
 
-  SharedHandle<AuthConfig> _authConfig;
+  SharedHandle<AuthConfig> authConfig_;
 
-  SharedHandle<Request> _proxyRequest;
+  SharedHandle<Request> proxyRequest_;
 
-  std::string getProxyAuthString() const;
+  bool noCache_;
+
+  bool acceptGzip_;
+
+  std::pair<std::string, std::string> getProxyAuthString() const;
 public:
   HttpRequest();
 
   const SharedHandle<Segment>& getSegment() const
   {
-    return segment;
+    return segment_;
   }
 
   void setSegment(const SharedHandle<Segment>& segment);
@@ -98,58 +102,58 @@ public:
 
   uint64_t getEntityLength() const
   {
-    assert(!_fileEntry.isNull());
-    return _fileEntry->getLength();
+    assert(!fileEntry_.isNull());
+    return fileEntry_->getLength();
   }
 
   const std::string& getHost() const
   {
-    return request->getHost();
+    return request_->getHost();
   }
 
   uint16_t getPort() const
   {
-    return request->getPort();
+    return request_->getPort();
   }
 
   const std::string& getMethod() const
   {
-    return request->getMethod();
+    return request_->getMethod();
   }
 
   const std::string& getProtocol() const
   {
-    return request->getProtocol();
+    return request_->getProtocol();
   }
 
   const std::string& getCurrentURI() const
   {
-    return request->getCurrentUrl();
+    return request_->getCurrentUri();
   }
   
   const std::string& getDir() const
   {
-    return request->getDir();
+    return request_->getDir();
   }
 
   const std::string& getFile() const
   {
-    return request->getFile();
+    return request_->getFile();
   }
 
   const std::string& getQuery() const
   {
-    return request->getQuery();
+    return request_->getQuery();
   }
 
   const std::string& getPreviousURI() const
   {
-    return request->getPreviousUrl();
+    return request_->getPreviousUri();
   }
 
   std::string getURIHost() const
   {
-    return request->getURIHost();
+    return request_->getURIHost();
   }
 
   SharedHandle<Range> getRange() const;
@@ -162,7 +166,7 @@ public:
 
   const SharedHandle<Request>& getRequest() const
   {
-    return request;
+    return request_;
   }
 
   off_t getStartByte() const;
@@ -172,8 +176,8 @@ public:
   /**
    * Returns string representation of http request.  It usually starts
    * with "GET ..." and ends with "\r\n".  The AuthConfig for this
-   * request is resolved using _authConfigFactory and stored in
-   * _authConfig.  getAuthConfig() returns AuthConfig used in the last
+   * request is resolved using authConfigFactory_ and stored in
+   * authConfig_.  getAuthConfig() returns AuthConfig used in the last
    * invocation of createRequest().
    */
   std::string createRequest();
@@ -190,7 +194,7 @@ public:
 
   void setUserAgent(const std::string& userAgent)
   {
-    this->userAgent = userAgent;
+    userAgent_ = userAgent;
   }
   
   // accepts multiline headers, delimited by LF
@@ -201,21 +205,21 @@ public:
   template<typename InputIterator>
   void addAcceptType(InputIterator first, InputIterator last)
   {
-    _acceptTypes.insert(_acceptTypes.end(), first, last);
+    acceptTypes_.insert(acceptTypes_.end(), first, last);
   }
 
   void setCookieStorage(const SharedHandle<CookieStorage>& cookieStorage);
 
   const SharedHandle<CookieStorage>& getCookieStorage() const
   {
-    return _cookieStorage;
+    return cookieStorage_;
   }
 
   void setAuthConfigFactory
   (const SharedHandle<AuthConfigFactory>& factory, const Option* option);
 
   /*
-   * To use proxy, pass proxy string to Request::setUrl() and set it this
+   * To use proxy, pass proxy string to Request::setUri() and set it this
    * object.
    */
   void setProxyRequest(const SharedHandle<Request>& proxyRequest);
@@ -236,18 +240,40 @@ public:
 
   void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
   {
-    _fileEntry = fileEntry;
+    fileEntry_ = fileEntry;
   }
 
   const SharedHandle<FileEntry>& getFileEntry() const
   {
-    return _fileEntry;
+    return fileEntry_;
+  }
+
+  void enableNoCache()
+  {
+    noCache_ = true;
+  }
+
+  void disableNoCache()
+  {
+    noCache_ = false;
+  }
+
+  void enableAcceptGZip()
+  {
+    acceptGzip_ = true;
+  }
+
+  void disableAcceptGZip()
+  {
+    acceptGzip_ = false;
+  }
+
+  bool acceptGZip() const
+  {
+    return acceptGzip_;
   }
 };
 
-typedef SharedHandle<HttpRequest> HttpRequestHandle;
-typedef std::deque<HttpRequestHandle> HttpRequests;
-
 } // namespace aria2
 
 #endif // _D_HTTP_REQUEST_H_
