@@ -53,6 +53,10 @@
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
@@ -65,11 +69,11 @@ HttpRequestCommand::HttpRequestCommand
  DownloadEngine* e,
  const SocketHandle& s)
   :AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-   _httpConnection(httpConnection)
+   httpConnection_(httpConnection)
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   disableReadCheckSocket();
-  setWriteCheckSocket(socket);
+  setWriteCheckSocket(getSocket());
 }
 
 HttpRequestCommand::~HttpRequestCommand() {}
@@ -111,65 +115,70 @@ createHttpRequest(const SharedHandle<Request>& req,
 
 bool HttpRequestCommand::executeInternal() {
   //socket->setBlockingMode();
-  if(req->getProtocol() == Request::PROTO_HTTPS) {
-    socket->prepareSecureConnection();
-    if(!socket->initiateSecureConnection(req->getHost())) {
-      setReadCheckSocketIf(socket, socket->wantRead());
-      setWriteCheckSocketIf(socket, socket->wantWrite());
-      e->commands.push_back(this);
+  if(getRequest()->getProtocol() == Request::PROTO_HTTPS) {
+    getSocket()->prepareSecureConnection();
+    if(!getSocket()->initiateSecureConnection(getRequest()->getHost())) {
+      setReadCheckSocketIf(getSocket(), getSocket()->wantRead());
+      setWriteCheckSocketIf(getSocket(), getSocket()->wantWrite());
+      getDownloadEngine()->addCommand(this);
       return false;
     }
   }
-  if(_httpConnection->sendBufferIsEmpty()) {
+  if(httpConnection_->sendBufferIsEmpty()) {
     if(!checkIfConnectionEstablished
-       (socket, _connectedHostname, _connectedAddr, _connectedPort)) {
+       (getSocket(), connectedHostname_, connectedAddr_, connectedPort_)) {
       return true;
     }
 
-    if(_segments.empty()) {
+    if(getSegments().empty()) {
       SharedHandle<HttpRequest> httpRequest
-        (createHttpRequest(req,
-                           _fileEntry,
+        (createHttpRequest(getRequest(),
+                           getFileEntry(),
                            SharedHandle<Segment>(),
-                           _requestGroup->getTotalLength(),
+                           getRequestGroup()->getTotalLength(),
                            getOption(),
-                           _requestGroup,
-                           e->getCookieStorage(),
-                           e->getAuthConfigFactory(),
-                           _proxyRequest));
-      _httpConnection->sendRequest(httpRequest);
+                           getRequestGroup(),
+                           getDownloadEngine()->getCookieStorage(),
+                           getDownloadEngine()->getAuthConfigFactory(),
+                           proxyRequest_));
+      httpConnection_->sendRequest(httpRequest);
     } else {
       for(std::vector<SharedHandle<Segment> >::const_iterator itr =
-            _segments.begin(), eoi = _segments.end(); itr != eoi; ++itr) {
+            getSegments().begin(), eoi = getSegments().end();
+          itr != eoi; ++itr) {
         const SharedHandle<Segment>& segment = *itr;
-        if(!_httpConnection->isIssued(segment)) {
+        if(!httpConnection_->isIssued(segment)) {
           SharedHandle<HttpRequest> httpRequest
-            (createHttpRequest(req,
-                               _fileEntry,
+            (createHttpRequest(getRequest(),
+                               getFileEntry(),
                                segment,
-                               _requestGroup->getTotalLength(),
+                               getRequestGroup()->getTotalLength(),
                                getOption(),
-                               _requestGroup,
-                               e->getCookieStorage(),
-                               e->getAuthConfigFactory(),
-                               _proxyRequest));
-          _httpConnection->sendRequest(httpRequest);
+                               getRequestGroup(),
+                               getDownloadEngine()->getCookieStorage(),
+                               getDownloadEngine()->getAuthConfigFactory(),
+                               proxyRequest_));
+          httpConnection_->sendRequest(httpRequest);
         }
       }
     }
   } else {
-    _httpConnection->sendPendingData();
+    httpConnection_->sendPendingData();
   }
-  if(_httpConnection->sendBufferIsEmpty()) {
-    Command* command = new HttpResponseCommand(cuid, req, _fileEntry,
-                                               _requestGroup,
-                                               _httpConnection, e, socket);
-    e->commands.push_back(command);
+  if(httpConnection_->sendBufferIsEmpty()) {
+    Command* command = new HttpResponseCommand(getCuid(),
+                                               getRequest(),
+                                               getFileEntry(),
+                                               getRequestGroup(),
+                                               httpConnection_,
+                                               getDownloadEngine(),
+                                               getSocket());
+    getDownloadEngine()->addCommand(command);
     return true;
   } else {
-    setReadCheckSocketIf(socket, socket->wantRead());
-    setWriteCheckSocketIf(socket, socket->wantWrite());
-    e->commands.push_back(this);
+    setReadCheckSocketIf(getSocket(), getSocket()->wantRead());
+    setWriteCheckSocketIf(getSocket(), getSocket()->wantWrite());
+    getDownloadEngine()->addCommand(this);
     return false;
   }
 }
@@ -177,7 +186,7 @@ bool HttpRequestCommand::executeInternal() {
 void HttpRequestCommand::setProxyRequest
 (const SharedHandle<Request>& proxyRequest)
 {
-  _proxyRequest = proxyRequest;
+  proxyRequest_ = proxyRequest;
 }
 
 } // namespace aria2
