@@ -38,10 +38,11 @@
 #include "common.h"
 
 #include <deque>
+#include <vector>
 #include <map>
 
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "Command.h"
 #include "BitfieldMan.h"
 
@@ -56,14 +57,11 @@ class PieceStorage;
 class Piece;
 class FileEntry;
 
-class SegmentEntry {
-public:
+struct SegmentEntry {
   cuid_t cuid;
   SharedHandle<Segment> segment;
-public:
-  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment);
-
-  ~SegmentEntry();
+  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment):
+    cuid(cuid), segment(segment) {}
 };
 
 typedef SharedHandle<SegmentEntry> SegmentEntryHandle;
@@ -74,34 +72,34 @@ typedef std::deque<SegmentEntryHandle> SegmentEntries;
  */
 class SegmentMan {
 private:
-  const Option* _option;
+  const Option* option_;
 
-  Logger* logger;
+  Logger* logger_;
 
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SegmentEntries usedSegmentEntries;
+  SegmentEntries usedSegmentEntries_;
 
   // Remember writtenLength for each segment. The key is an index of a
   // segment. The value is writtenLength for that segment.
-  std::map<size_t, size_t> _segmentWrittenLengthMemo;
+  std::map<size_t, size_t> segmentWrittenLengthMemo_;
 
   // Used for calculating download speed.
-  std::deque<SharedHandle<PeerStat> > peerStats;
+  std::vector<SharedHandle<PeerStat> > peerStats_;
 
   // Keep track of fastest PeerStat for each server
-  std::deque<SharedHandle<PeerStat> > _fastestPeerStats;
+  std::vector<SharedHandle<PeerStat> > fastestPeerStats_;
 
   // key: PeerStat's cuid, value: its download speed
-  std::map<cuid_t, unsigned int> _peerStatDlspdMap;
+  std::map<cuid_t, unsigned int> peerStatDlspdMap_;
 
-  Time _lastPeerStatDlspdMapUpdated;
+  Timer lastPeerStatDlspdMapUpdated_;
 
-  unsigned int _cachedDlspd;
+  unsigned int cachedDlspd_;
 
-  BitfieldMan _ignoreBitfield;
+  BitfieldMan ignoreBitfield_;
 
   SharedHandle<Segment> checkoutSegment(cuid_t cuid,
                                         const SharedHandle<Piece>& piece);
@@ -137,14 +135,14 @@ public:
    * Fill segments which are assigned to the command whose CUID is cuid.
    * This function doesn't clear passed segments.
    */
-  void getInFlightSegment(std::deque<SharedHandle<Segment> >& segments,
+  void getInFlightSegment(std::vector<SharedHandle<Segment> >& segments,
                           cuid_t cuid);
 
   SharedHandle<Segment> getSegment(cuid_t cuid);
 
   // Checkouts segments in the range of fileEntry and push back to
   // segments until segments.size() < maxSegments holds false
-  void getSegment(std::deque<SharedHandle<Segment> >& segments,
+  void getSegment(std::vector<SharedHandle<Segment> >& segments,
                   cuid_t cuid,
                   const SharedHandle<FileEntry>& fileEntry,
                   size_t maxSegments);
@@ -156,6 +154,13 @@ public:
    * whose isNull call is true.
    */
   SharedHandle<Segment> getSegment(cuid_t cuid, size_t index);
+
+  // Returns a currently used segment whose index is index and written
+  // length is 0.  The current owner(in idle state) of segment cancels
+  // the segment and cuid command acquires the ownership of the
+  // segment.  If no such segment exists, returns null.
+  SharedHandle<Segment> getCleanSegmentIfOwnerIsIdle(cuid_t cuid, size_t index);
+
   /**
    * Updates download status.
    */
@@ -168,6 +173,10 @@ public:
 
   void cancelSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
 
+  void cancelAllSegments();
+
+  void eraseSegmentWrittenLengthMemo();
+
   /**
    * Tells SegmentMan that the segment has been downloaded successfully.
    */
@@ -193,25 +202,27 @@ public:
   uint64_t getDownloadLength() const;
 
 
-  // If there is inactive PeerStat in peerStats, it is replaced with
+  // If there is inactive PeerStat in peerStats_, it is replaced with
   // given peerStat. If no such PeerStat exist, the given peerStat is
   // inserted.
   void registerPeerStat(const SharedHandle<PeerStat>& peerStat);
 
-  const std::deque<SharedHandle<PeerStat> >& getPeerStats() const
+  const std::vector<SharedHandle<PeerStat> >& getPeerStats() const
   {
-    return peerStats;
+    return peerStats_;
   }
 
+  SharedHandle<PeerStat> getPeerStat(cuid_t cuid) const;
+
   // If there is slower PeerStat than given peerStat for the same
-  // hostname and protocol in _fastestPeerStats, the former is
+  // hostname and protocol in fastestPeerStats_, the former is
   // replaced with latter. If there are no PeerStat with same hostname
   // and protocol with given peerStat, given peerStat is inserted.
   void updateFastestPeerStat(const SharedHandle<PeerStat>& peerStat);
 
-  const std::deque<SharedHandle<PeerStat> >& getFastestPeerStats() const
+  const std::vector<SharedHandle<PeerStat> >& getFastestPeerStats() const
   {
-    return _fastestPeerStats;
+    return fastestPeerStats_;
   }
 
   /**
@@ -237,8 +248,6 @@ public:
   bool allSegmentsIgnored() const;
 };
 
-typedef SharedHandle<SegmentMan> SegmentManHandle;
-
 } // namespace aria2
 
 #endif // _D_SEGMENT_MAN_H_
