@@ -47,9 +47,9 @@ namespace aria2 {
 
 class Time {
 private:
-  struct timeval tv;
+  struct timeval tv_;
 
-  bool _good;
+  bool good_;
 
   struct timeval getCurrentTime() const;
 public:
@@ -77,10 +77,20 @@ public:
 
   time_t difference(const struct timeval& now) const;
 
+  time_t difference(const Time& now) const
+  {
+    return difference(now.tv_);
+  }
+
   int64_t differenceInMillis() const;
 
   int64_t differenceInMillis(const struct timeval& now) const;
 
+  int64_t differenceInMillis(const Time& now) const
+  {
+    return differenceInMillis(now.tv_);
+  }
+
   // Returns true if this object's time value is zero.
   bool isZero() const;
 
@@ -95,6 +105,8 @@ public:
 
   bool isNewer(const Time& time) const;
 
+  void advance(time_t sec);
+
   bool good() const;
 
   // Returns !good()
