@@ -61,6 +61,7 @@
 #include "ByteArrayDiskWriter.h"
 #include "a2functional.h"
 #include "ByteArrayDiskWriterFactory.h"
+#include "MetadataInfo.h"
 #ifdef ENABLE_BITTORRENT
 # include "bittorrent_helper.h"
 # include "BtConstants.h"
@@ -130,6 +131,8 @@ const std::set<std::string>& listRequestOptions()
     PREF_BT_SEED_UNVERIFIED,
     PREF_BT_STOP_TIMEOUT,
     PREF_BT_TRACKER_INTERVAL,
+    PREF_BT_TRACKER_TIMEOUT,
+    PREF_BT_TRACKER_CONNECT_TIMEOUT,
     PREF_ENABLE_PEER_EXCHANGE,
     PREF_FOLLOW_TORRENT,
     PREF_INDEX_OUT,
@@ -152,12 +155,14 @@ const std::set<std::string>& listRequestOptions()
     PREF_MAX_DOWNLOAD_LIMIT,
     PREF_NO_FILE_ALLOCATION_LIMIT,
     PREF_PARAMETERIZED_URI,
-    PREF_REALTIME_CHUNK_CHECKSUM
+    PREF_REALTIME_CHUNK_CHECKSUM,
+    PREF_REMOVE_CONTROL_FILE,
+    PREF_ALWAYS_RESUME,
+    PREF_MAX_RESUME_FAILURE_TRIES,
+    PREF_HTTP_ACCEPT_GZIP
   };
   static std::set<std::string> requestOptions
-    (&REQUEST_OPTIONS[0],
-     &REQUEST_OPTIONS[arrayLength(REQUEST_OPTIONS)]);;
-
+    (vbegin(REQUEST_OPTIONS), vend(REQUEST_OPTIONS));
   return requestOptions;
 }
 
@@ -208,6 +213,16 @@ static SharedHandle<RequestGroup> createRequestGroup
   return rg;
 }
 
+static SharedHandle<MetadataInfo> createMetadataInfo(const std::string& uri)
+{
+  return SharedHandle<MetadataInfo>(new MetadataInfo(uri));
+}
+
+static SharedHandle<MetadataInfo> createMetadataInfoDataOnly()
+{
+  return SharedHandle<MetadataInfo>(new MetadataInfo());
+}
+
 #ifdef ENABLE_BITTORRENT
 
 static
@@ -222,10 +237,12 @@ createBtRequestGroup(const std::string& torrentFilePath,
   dctx->setDir(option->get(PREF_DIR));
   if(torrentData.empty()) {
     bittorrent::load(torrentFilePath, dctx, auxUris);// may throw exception
+    rg->setMetadataInfo(createMetadataInfo(torrentFilePath));
   } else {
     bittorrent::loadFromMemory(torrentData, dctx, auxUris, "default"); // may
     // throw
     // exception
+    rg->setMetadataInfo(createMetadataInfoDataOnly());
   }
   dctx->setFileFilter(util::parseIntRange(option->get(PREF_SELECT_FILE)));
   std::istringstream indexOutIn(option->get(PREF_INDEX_OUT));
@@ -237,6 +254,9 @@ createBtRequestGroup(const std::string& torrentFilePath,
       ((*i).first, util::applyDir(dctx->getDir(), (*i).second));
   }
   rg->setDownloadContext(dctx);
+  // Remove "metalink" from Accept Type list to avoid server from
+  // responding Metalink file for web-seeding URIs.
+  util::removeMetalinkContentTypes(rg);
   return rg;
 }
 
@@ -256,8 +276,9 @@ createBtMagnetRequestGroup(const std::string& magnetLink,
   rg->setFileAllocationEnabled(false);
   rg->setPreLocalFileCheckEnabled(false);
   bittorrent::loadMagnet(magnetLink, dctx);
-  dctx->getFirstFileEntry()->setPath
-    (dctx->getAttribute(bittorrent::BITTORRENT)[bittorrent::NAME].s());
+  SharedHandle<TorrentAttribute> torrentAttrs =
+    bittorrent::getTorrentAttrs(dctx);
+  dctx->getFirstFileEntry()->setPath(torrentAttrs->name);
   rg->setDownloadContext(dctx);
   rg->clearPostDownloadHandler();
   rg->addPostDownloadHandler
@@ -265,6 +286,7 @@ createBtMagnetRequestGroup(const std::string& magnetLink,
      (new UTMetadataPostDownloadHandler()));
   rg->setDiskWriterFactory
     (SharedHandle<DiskWriterFactory>(new ByteArrayDiskWriterFactory()));
+  rg->setMetadataInfo(createMetadataInfo(magnetLink));
   return rg;
 }
 
@@ -308,54 +330,51 @@ void createRequestGroupForMetalink
     dw->setString(metalinkData);
     Metalink2RequestGroup().generate(result, dw, option);
   }
-  if(result.empty()) {
-    throw DL_ABORT_EX(MSG_NO_FILES_TO_DOWNLOAD);
-  }
 }
 #endif // ENABLE_METALINK
 
 class AccRequestGroup {
 private:
-  std::vector<SharedHandle<RequestGroup> >& _requestGroups;
-  ProtocolDetector _detector;
-  SharedHandle<Option> _option;
-  bool _ignoreLocalPath;
+  std::vector<SharedHandle<RequestGroup> >& requestGroups_;
+  ProtocolDetector detector_;
+  SharedHandle<Option> option_;
+  bool ignoreLocalPath_;
 public:
   AccRequestGroup(std::vector<SharedHandle<RequestGroup> >& requestGroups,
                   const SharedHandle<Option>& option,
                   bool ignoreLocalPath = false):
-    _requestGroups(requestGroups), _option(option),
-    _ignoreLocalPath(ignoreLocalPath) {}
+    requestGroups_(requestGroups), option_(option),
+    ignoreLocalPath_(ignoreLocalPath) {}
 
   void
   operator()(const std::string& uri)
   {
-    if(_detector.isStreamProtocol(uri)) {
+    if(detector_.isStreamProtocol(uri)) {
       std::vector<std::string> streamURIs;
-      size_t numSplit = _option->getAsInt(PREF_SPLIT);
+      size_t numSplit = option_->getAsInt(PREF_SPLIT);
       for(size_t i = 0; i < numSplit; ++i) {
         streamURIs.push_back(uri);
       }
       SharedHandle<RequestGroup> rg =
-        createRequestGroup(_option, streamURIs);
+        createRequestGroup(option_, streamURIs);
       rg->setNumConcurrentCommand(numSplit);
-      _requestGroups.push_back(rg);
+      requestGroups_.push_back(rg);
     }
 #ifdef ENABLE_BITTORRENT
-    else if(_detector.guessTorrentMagnet(uri)) {
+    else if(detector_.guessTorrentMagnet(uri)) {
       try {
         SharedHandle<RequestGroup> group =
-          createBtMagnetRequestGroup(uri, _option, std::vector<std::string>());
-        _requestGroups.push_back(group);
+          createBtMagnetRequestGroup(uri, option_, std::vector<std::string>());
+        requestGroups_.push_back(group);
       } catch(RecoverableException& e) {
         // error occurred while parsing torrent file.
         // We simply ignore it. 
         LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
       }
-    } else if(!_ignoreLocalPath && _detector.guessTorrentFile(uri)) {
+    } else if(!ignoreLocalPath_ && detector_.guessTorrentFile(uri)) {
       try {
-        _requestGroups.push_back
-          (createBtRequestGroup(uri, _option, std::vector<std::string>()));
+        requestGroups_.push_back
+          (createBtRequestGroup(uri, option_, std::vector<std::string>()));
       } catch(RecoverableException& e) {
         // error occurred while parsing torrent file.
         // We simply ignore it. 
@@ -364,9 +383,9 @@ public:
     } 
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
-    else if(!_ignoreLocalPath && _detector.guessMetalinkFile(uri)) {
+    else if(!ignoreLocalPath_ && detector_.guessMetalinkFile(uri)) {
       try {
-        Metalink2RequestGroup().generate(_requestGroups, uri, _option);
+        Metalink2RequestGroup().generate(requestGroups_, uri, option_);
       } catch(RecoverableException& e) {
         // error occurred while parsing metalink file.
         // We simply ignore it.
@@ -382,10 +401,10 @@ public:
 
 class StreamProtocolFilter {
 private:
-  ProtocolDetector _detector;
+  ProtocolDetector detector_;
 public:
   bool operator()(const std::string& uri) {
-    return _detector.isStreamProtocol(uri);
+    return detector_.isStreamProtocol(uri);
   }
 };
 
@@ -469,4 +488,19 @@ void createRequestGroupForUriList
   }
 }
 
+SharedHandle<MetadataInfo>
+createMetadataInfoFromFirstFileEntry(const SharedHandle<DownloadContext>& dctx)
+{
+  if(dctx->getFileEntries().empty()) {
+    return SharedHandle<MetadataInfo>();
+  } else {
+    std::vector<std::string> uris;
+    dctx->getFileEntries()[0]->getUris(uris);
+    if(uris.empty()) {
+      return SharedHandle<MetadataInfo>();
+    }
+    return SharedHandle<MetadataInfo>(new MetadataInfo(uris[0]));
+  }
+}
+
 } // namespace aria2
