@@ -35,14 +35,14 @@ class DefaultBtAnnounceTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testProcessAnnounceResponse);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<DownloadContext> _dctx;
-  SharedHandle<MockPieceStorage> _pieceStorage;
-  SharedHandle<MockPeerStorage> _peerStorage;
-  SharedHandle<BtRuntime> _btRuntime;
-  Option* _option;
+  SharedHandle<DownloadContext> dctx_;
+  SharedHandle<MockPieceStorage> pieceStorage_;
+  SharedHandle<MockPeerStorage> peerStorage_;
+  SharedHandle<BtRuntime> btRuntime_;
+  Option* option_;
 public:
   void setUp() {
-    _option = new Option();
+    option_ = new Option();
 
     int64_t totalLength = 4*1024*1024;
     int32_t pieceLength = 256*1024;
@@ -55,30 +55,29 @@ public:
     
     std::string peerId = "-aria2-ultrafastdltl";
 
-    _dctx.reset(new DownloadContext(pieceLength, totalLength));
-    BDE torrentAttrs = BDE::dict();
-    torrentAttrs[bittorrent::INFO_HASH] =
-      std::string(&infoHash[0], &infoHash[arrayLength(infoHash)]);
-    _dctx->setAttribute(bittorrent::BITTORRENT, torrentAttrs);
+    dctx_.reset(new DownloadContext(pieceLength, totalLength));
+    SharedHandle<TorrentAttribute> torrentAttrs(new TorrentAttribute());
+    torrentAttrs->infoHash = std::string(vbegin(infoHash), vend(infoHash));
+    dctx_->setAttribute(bittorrent::BITTORRENT, torrentAttrs);
     bittorrent::setStaticPeerId(peerId);
 
-    _pieceStorage.reset(new MockPieceStorage());
-    _pieceStorage->setTotalLength(totalLength);
-    _pieceStorage->setCompletedLength(pieceLength*10);
+    pieceStorage_.reset(new MockPieceStorage());
+    pieceStorage_->setTotalLength(totalLength);
+    pieceStorage_->setCompletedLength(pieceLength*10);
 
-    _peerStorage.reset(new MockPeerStorage());
+    peerStorage_.reset(new MockPeerStorage());
     TransferStat stat;
     stat.setSessionDownloadLength(pieceLength*5);
     stat.setSessionUploadLength(pieceLength*6);
-    _peerStorage->setStat(stat);
+    peerStorage_->setStat(stat);
 
-    _btRuntime.reset(new BtRuntime());
-    _btRuntime->setListenPort(6989);
+    btRuntime_.reset(new BtRuntime());
+    btRuntime_->setListenPort(6989);
   }
 
   void tearDown()
   {
-    delete _option;
+    delete option_;
   }
 
   void testGetAnnounceUrl();
@@ -97,41 +96,53 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(DefaultBtAnnounceTest);
 
 template<typename InputIterator>
-static BDE createAnnounceTier(InputIterator first, InputIterator last)
+static SharedHandle<List> createAnnounceTier
+(InputIterator first, InputIterator last)
 {
-  BDE announceTier = BDE::list();
+  SharedHandle<List> announceTier = List::g();
   for(; first != last; ++first) {
-    announceTier << BDE(*first);
+    announceTier->append(String::g(*first));
   }
   return announceTier;
 }
 
-static BDE createAnnounceTier(const std::string& uri)
+static SharedHandle<List> createAnnounceTier(const std::string& uri)
 {
-  BDE announceTier = BDE::list();
-  announceTier << uri;
+  SharedHandle<List> announceTier = List::g();
+  announceTier->append(String::g(uri));
   return announceTier;
 }
 
 static void setAnnounceList(const SharedHandle<DownloadContext>& dctx,
-                            const BDE& announceList)
+                            const SharedHandle<List>& announceList)
 {
-  dctx->getAttribute(bittorrent::BITTORRENT)[bittorrent::ANNOUNCE_LIST] =
-    announceList;
+  std::vector<std::vector<std::string> > dest;
+  for(List::ValueType::const_iterator tierIter = announceList->begin(),
+        eoi = announceList->end(); tierIter != eoi; ++tierIter) {
+    std::vector<std::string> ntier;
+    const List* tier = asList(*tierIter);
+    for(List::ValueType::const_iterator uriIter = tier->begin(),
+          eoi2 = tier->end(); uriIter != eoi2; ++uriIter) {
+      const String* uri = asString(*uriIter);
+      ntier.push_back(uri->s());
+    }
+    dest.push_back(ntier);
+  }
+  bittorrent::getTorrentAttrs(dctx)->announceList.swap(dest);
 }
 
 void DefaultBtAnnounceTest::testNoMoreAnnounce()
 {
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier("http://localhost/announce");
-  announceList << createAnnounceTier("http://backup/announce");
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier("http://localhost/announce"));
+  announceList->append(createAnnounceTier("http://backup/announce"));
 
-  setAnnounceList(_dctx, announceList);
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
@@ -146,7 +157,7 @@ void DefaultBtAnnounceTest::testNoMoreAnnounce()
 
   btAnnounce.announceSuccess();
 
-  _pieceStorage->setAllDownloadFinished(true);
+  pieceStorage_->setAllDownloadFinished(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=completed&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -156,7 +167,7 @@ void DefaultBtAnnounceTest::testNoMoreAnnounce()
 
   btAnnounce.announceSuccess();
 
-  _btRuntime->setHalt(true);
+  btRuntime_->setHalt(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=0&no_peer_id=1&port=6989&event=stopped&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -172,14 +183,14 @@ void DefaultBtAnnounceTest::testNoMoreAnnounce()
 void DefaultBtAnnounceTest::testGetAnnounceUrl()
 {
 
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier("http://localhost/announce");  
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier("http://localhost/announce"));
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
@@ -190,27 +201,27 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl()
 
   btAnnounce.announceSuccess();
 
-  _pieceStorage->setAllDownloadFinished(true);
+  pieceStorage_->setAllDownloadFinished(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=completed&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
   btAnnounce.announceSuccess();
 
-  _btRuntime->setHalt(true);
+  btRuntime_->setHalt(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=0&no_peer_id=1&port=6989&event=stopped&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 }
 
 void DefaultBtAnnounceTest::testGetAnnounceUrl_withQuery()
 {
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier("http://localhost/announce?k=v");
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier("http://localhost/announce?k=v"));
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL
@@ -225,15 +236,15 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl_withQuery()
 
 void DefaultBtAnnounceTest::testGetAnnounceUrl_externalIP()
 {
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier("http://localhost/announce");
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier("http://localhost/announce"));
+  setAnnounceList(dctx_, announceList);
 
-  _option->put(PREF_BT_EXTERNAL_IP, "192.168.1.1");
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  option_->put(PREF_BT_EXTERNAL_IP, "192.168.1.1");
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL
@@ -248,15 +259,15 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl_externalIP()
 
 void DefaultBtAnnounceTest::testIsAllAnnounceFailed()
 {
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier("http://localhost/announce");
-  announceList << createAnnounceTier("http://backup/announce");
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier("http://localhost/announce"));
+  announceList->append(createAnnounceTier("http://backup/announce"));
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
@@ -281,21 +292,21 @@ void DefaultBtAnnounceTest::testURLOrderInStoppedEvent()
   const char* urls[] = { "http://localhost1/announce",
                          "http://localhost2/announce" };
 
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier(&urls[0], &urls[arrayLength(urls)]);
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier(vbegin(urls), vend(urls)));
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
   btAnnounce.announceSuccess();
 
-  _btRuntime->setHalt(true);
+  btRuntime_->setHalt(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=0&no_peer_id=1&port=6989&event=stopped&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -311,21 +322,21 @@ void DefaultBtAnnounceTest::testURLOrderInCompletedEvent()
   const char* urls[] = { "http://localhost1/announce",
                          "http://localhost2/announce" };
 
-  BDE announceList = BDE::list();
-  announceList << createAnnounceTier(&urls[0], &urls[arrayLength(urls)]);
-  setAnnounceList(_dctx, announceList);
+  SharedHandle<List> announceList = List::g();
+  announceList->append(createAnnounceTier(vbegin(urls), vend(urls)));
+  setAnnounceList(dctx_, announceList);
 
-  DefaultBtAnnounce btAnnounce(_dctx, _option);
-  btAnnounce.setPieceStorage(_pieceStorage);
-  btAnnounce.setPeerStorage(_peerStorage);
-  btAnnounce.setBtRuntime(_btRuntime);
+  DefaultBtAnnounce btAnnounce(dctx_, option_);
+  btAnnounce.setPieceStorage(pieceStorage_);
+  btAnnounce.setPeerStorage(peerStorage_);
+  btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
   btAnnounce.announceSuccess();
 
-  _pieceStorage->setAllDownloadFinished(true);
+  pieceStorage_->setAllDownloadFinished(true);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=completed&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -340,7 +351,7 @@ void DefaultBtAnnounceTest::testProcessAnnounceResponse_malformed()
 {
   try {
     std::string res = "i123e";
-    DefaultBtAnnounce(_dctx, _option).processAnnounceResponse(reinterpret_cast<const unsigned char*>(res.c_str()), res.size());
+    DefaultBtAnnounce(dctx_, option_).processAnnounceResponse(reinterpret_cast<const unsigned char*>(res.c_str()), res.size());
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
     std::cerr << e.stackTrace() << std::endl;
@@ -351,7 +362,7 @@ void DefaultBtAnnounceTest::testProcessAnnounceResponse_failureReason()
 {
   try {
     std::string res = "d14:failure reason11:hello worlde";
-    DefaultBtAnnounce(_dctx, _option).processAnnounceResponse(reinterpret_cast<const unsigned char*>(res.c_str()), res.size());
+    DefaultBtAnnounce(dctx_, option_).processAnnounceResponse(reinterpret_cast<const unsigned char*>(res.c_str()), res.size());
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
     std::cerr << e.stackTrace() << std::endl;
@@ -369,7 +380,7 @@ void DefaultBtAnnounceTest::testProcessAnnounceResponse()
     "10:incompletei200e"
     "e";
   
-  DefaultBtAnnounce an(_dctx, _option);
+  DefaultBtAnnounce an(dctx_, option_);
   an.processAnnounceResponse(reinterpret_cast<const unsigned char*>(res.c_str()), res.size());
   CPPUNIT_ASSERT_EQUAL(std::string("foo"), an.getTrackerID());
   CPPUNIT_ASSERT_EQUAL((time_t)3000, an.getInterval());
