@@ -23,8 +23,8 @@ private:
   SharedHandle<DiskAdaptor> diskAdaptor;
   std::deque<size_t> pieceLengthList;
   std::deque<SharedHandle<Piece> > inFlightPieces;
-  bool _downloadFinished;
-  bool _allDownloadFinished;
+  bool downloadFinished_;
+  bool allDownloadFinished_;
 public:
   MockPieceStorage():totalLength(0),
                      filteredTotalLength(0),
@@ -33,8 +33,8 @@ public:
                      bitfieldMan(0),
                      selectiveDownloadingMode(false),
                      endGame(false),
-                     _downloadFinished(false),
-                     _allDownloadFinished(false) {}
+                     downloadFinished_(false),
+                     allDownloadFinished_(false) {}
 
   virtual ~MockPieceStorage() {}
 
@@ -49,7 +49,7 @@ public:
   }
 
   virtual SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes)
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
   {
     return SharedHandle<Piece>(new Piece());
   }
@@ -59,7 +59,7 @@ public:
   }
 
   virtual SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes)
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
   {
     return SharedHandle<Piece>(new Piece());
   }
@@ -140,21 +140,21 @@ public:
   virtual void clearFileFilter() {}
 
   virtual bool downloadFinished() {
-    return _downloadFinished;
+    return downloadFinished_;
   }
 
   void setDownloadFinished(bool f)
   {
-    _downloadFinished = f;
+    downloadFinished_ = f;
   }
 
   virtual bool allDownloadFinished() {
-    return _allDownloadFinished;
+    return allDownloadFinished_;
   }
 
   void setAllDownloadFinished(bool f)
   {
-    _allDownloadFinished = f;
+    allDownloadFinished_ = f;
   }
 
   virtual void initStorage() {}
@@ -210,18 +210,18 @@ public:
     pieceLengthList.push_back(length);
   }
 
-  virtual void advertisePiece(int32_t cuid, size_t index) {}
+  virtual void advertisePiece(cuid_t cuid, size_t index) {}
 
-  virtual void getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-                                         int32_t myCuid,
-                                         const Time& lastCheckTime)
+  virtual void getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
+                                         cuid_t myCuid,
+                                         const Timer& lastCheckTime)
   {}
 
   virtual void removeAdvertisedPiece(time_t elapsed) {}
 
   virtual void markAllPiecesDone() {}
 
-  virtual void addInFlightPiece(const std::deque<SharedHandle<Piece> >& pieces)
+  virtual void addInFlightPiece(const std::vector<SharedHandle<Piece> >& pieces)
   {
     std::copy(pieces.begin(), pieces.end(), back_inserter(inFlightPieces));
   }
@@ -231,7 +231,7 @@ public:
     return inFlightPieces.size();
   }
 
-  virtual void getInFlightPieces(std::deque<SharedHandle<Piece> >& pieces)
+  virtual void getInFlightPieces(std::vector<SharedHandle<Piece> >& pieces)
   {
     pieces.insert(pieces.end(), inFlightPieces.begin(), inFlightPieces.end());
   }
